(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    213815,       4568]
NotebookOptionsPosition[    209738,       4436]
NotebookOutlinePosition[    210093,       4452]
CellTagsIndexPosition[    210050,       4449]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "The MDPDist ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package"
}], "Title",
 CellChangeTimes->{{3.573275521232416*^9, 3.573275573209074*^9}}],

Cell["\<\
On-the-fly exact computation of bisimilarity distances for Markov Decision \
Process with rewards\
\>", "Subtitle",
 CellChangeTimes->{{3.573275583316822*^9, 3.5732756585481663`*^9}}],

Cell["\<\
Authors: Giorgio Bacci, Giovanni Bacci, Kim G. Larsen, and Radu Mardare\
\>", "Subsubtitle",
 CellChangeTimes->{{3.5732756680995207`*^9, 3.573275700278157*^9}}],

Cell[TextData[{
 "In this tutorial we present the main features of the MDPDist package. This ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "package implements an on-the-fly method for computing the bisimilarity \
pseudometric of Ferns et al. [",
 ButtonBox["1",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dl.acm.org/citation.cfm?id=1036843.1036863"], None},
  ButtonNote->"http://dl.acm.org/citation.cfm?id=1036843.1036863"],
 "]",
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 "for Markov Decision Process with rewards. The algorithm implemented in this \
package is an exension of the on-the-fly method recently proposed in [",
 ButtonBox["2",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1007/978-3-642-36742-7_1"], None},
  ButtonNote->"http://dx.doi.org/10.1007/978-3-642-36742-7_1"],
 "] for Markov Chains."
}], "Text",
 CellChangeTimes->{{3.573275722916422*^9, 3.5732757291304398`*^9}, {
   3.5732758139748507`*^9, 3.5732758225254374`*^9}, {3.573275865055274*^9, 
   3.573275963961692*^9}, {3.573276041381415*^9, 3.573276041384344*^9}, {
   3.573278012419257*^9, 3.573278012512322*^9}, 3.573456379559987*^9}],

Cell[CellGroupData[{

Cell["Preliminaries", "Subsection",
 CellChangeTimes->{{3.57319656642203*^9, 3.5731965886116333`*^9}, {
  3.573197428245351*^9, 3.573197437170992*^9}, {3.573198785171384*^9, 
  3.5731988074631557`*^9}, {3.573455423365095*^9, 3.573455426402162*^9}}],

Cell[CellGroupData[{

Cell["\<\
Markov Decision Processes and Bisimulation\
\>", "Subsubsection",
 CellChangeTimes->{
  3.573197424344139*^9, {3.573198744758198*^9, 3.5731987631858892`*^9}}],

Cell[TextData[{
 "A ",
 StyleBox["probability distribution",
  FontSlant->"Italic"],
 " over a nonempty enumerable set S is a function \[Mu] : S \[RightArrow] \
[0,1] such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{"s", " ", "\[Element]", " ", "S"}]], 
     RowBox[{"\[Mu]", "(", "s", ")"}]}], " ", "=", " ", "1"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". We denote by \[CapitalDelta](S) the set of probability distributions over \
S."
}], "Text",
 CellChangeTimes->{{3.57319508037649*^9, 3.5731952940149393`*^9}}],

Cell[TextData[{
 StyleBox["Definition (Markov Decision Process).",
  FontWeight->"Bold"],
 " A Markov Decision Process with rewads (MDP) is a tuple \[ScriptCapitalM] \
=(S,A,\[Tau],\[Rho]) consisting of a finite nonempty set S of ",
 StyleBox["states",
  FontSlant->"Italic"],
 ", a finite nonempty set A of ",
 StyleBox["actions",
  FontSlant->"Italic"],
 ", a ",
 StyleBox["transition function",
  FontSlant->"Italic"],
 " \[Tau] : S \[Times] S \[RightArrow] \[CapitalDelta](S), and a ",
 StyleBox["reward function",
  FontSlant->"Italic"],
 " \[Tau] \[Colon] S \[Times] A \[RightArrow] \[DoubleStruckCapitalR]. "
}], "Text",
 CellChangeTimes->{{3.573189754253881*^9, 3.573189771202866*^9}, {
  3.57318991329031*^9, 3.5731901202180223`*^9}, {3.573190161329068*^9, 
  3.573190218003675*^9}, {3.573190299726532*^9, 3.573190300694838*^9}, {
  3.573196791621649*^9, 3.573196818298107*^9}}],

Cell[TextData[{
 "The operational behavior of an MDP \[ScriptCapitalM] =(S,A,\[Tau],\[Rho]) \
is as follows: the process in the state ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "0"], "\[Element]", " ", "S"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " chooses nondeterministically an action a \[Element] A and it changes the \
state to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "1"], "\[Element]", " ", "S"}], TraditionalForm]]],
 ", with the probabilty \[Tau](",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 ",a)(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 "). The choice of the action a made in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 "is rewarded by \[Rho](",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 ",a). The ",
 StyleBox["exectutions",
  FontSlant->"Italic"],
 " are transition sequences w = (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "0"], TraditionalForm]]],
 "),(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 "),....; the challenge is to find strategies for choosing the actions in \
order to maximize the ",
 StyleBox["accumulated reward",
  FontSlant->"Italic"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "\[Lambda]"], "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"i", " ", "\[Element]", " ", "\[DoubleStruckCapitalN]"}]}]], 
     RowBox[{
      SuperscriptBox["\[Lambda]", "i"], 
      RowBox[{"\[Rho]", "(", 
       RowBox[{
        FormBox[
         SubscriptBox["s", "i"],
         TraditionalForm], ",", 
        FormBox[
         SubscriptBox["a", "i"],
         TraditionalForm]}], ")"}]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", where \[Lambda] \[Element] (0,1) is the discount factor. A ",
 StyleBox["strategy",
  FontSlant->"Italic"],
 " is given by a function \[Pi] : S \[RightArrow] \[CapitalDelta](A), called ",
 StyleBox["policy",
  FontSlant->"Italic"],
 ", where \[Pi](",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 ")(a) is the probabilty distribution over executions defined, for arbitrary \
w = (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "0"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "0"], TraditionalForm]]],
 "),(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "1"], TraditionalForm]]],
 ")...., by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["P", "\[Pi]"], "(", "w", ")"}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["\[Product]", 
      RowBox[{" ", 
       RowBox[{"i", " ", "\[Element]", " ", "\[DoubleStruckCapitalN]"}]}]], 
     RowBox[{
      RowBox[{"\[Pi]", "(", 
       SubscriptBox["s", "i"], ")"}], 
      RowBox[{
       RowBox[{"(", 
        SubscriptBox["a", "i"], ")"}], " ", "\[CenterDot]", " ", 
       RowBox[{"\[Tau]", "(", 
        RowBox[{
         SubscriptBox["s", "i"], ",", 
         SubscriptBox["a", "i"]}], ")"}]}], 
      RowBox[{"(", 
       SubscriptBox["s", 
        RowBox[{"i", "+", "1"}]], ")"}]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The ",
 StyleBox["value",
  FontSlant->"Italic"],
 " of ",
 Cell[BoxData[
  FormBox["s", TraditionalForm]]],
 " according to \[Pi] is characterized by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["V", "\[Pi]"], "(", "s", ")"}], "=", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"w", " ", "\[Element]", " ", 
        RowBox[{"\[CapitalOmega]", "(", "s", ")"}]}]}]], 
     RowBox[{
      RowBox[{
       SubscriptBox["R", "\[Lambda]"], "(", "w", ")"}], " ", 
      RowBox[{
       SuperscriptBox["P", "\[Pi]"], "(", "w", ")"}]}]}]}], TraditionalForm]],
  
  FormatType->"TraditionalForm"],
 ", where \[CapitalOmega](w) is the set of executions from s."
}], "Text",
 CellChangeTimes->{{3.573195311022274*^9, 3.573195700389303*^9}, {
   3.573195735203608*^9, 3.5731963952066917`*^9}, {3.573196428746313*^9, 
   3.573196525582459*^9}, 3.573196557870187*^9, {3.573197272304716*^9, 
   3.5731972800479794`*^9}}],

Cell[TextData[{
 StyleBox["Definition (Stocastic Bisimulation).",
  FontWeight->"Bold"],
 " Let \[ScriptCapitalM] =(S,A,\[Tau],\[Rho]) be an MDP. An equivalence \
relation R \[SubsetEqual] S \[Times] S is a ",
 StyleBox["stocatic bisimulation",
  FontSlant->"Italic"],
 " if whenever (s,t) \[Element] R then, for all a \[Element] A, \[Rho](s,a) = \
\[Rho](t,a) and, for all R-equivalence classes C, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"v", " ", "\[Element]", " ", "C"}]}]], 
     RowBox[{
      RowBox[{"\[Tau]", "(", 
       RowBox[{"s", ",", "a"}], ")"}], 
      RowBox[{"(", "v", ")"}]}]}], " ", "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"v", " ", "\[Element]", " ", "C"}]}]], 
     RowBox[{
      RowBox[{"\[Tau]", "(", 
       RowBox[{"t", ",", "a"}], ")"}], 
      RowBox[{"(", "v", ")"}]}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Two states s,t \[Element] S are ",
 StyleBox["stocatic bisimilar",
  FontSlant->"Italic"],
 ", written s \[Tilde] t, if they are related by some stochastic bisimulation \
on \[ScriptCapitalM]."
}], "Text",
 CellChangeTimes->{{3.573196756023551*^9, 3.573197174976747*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bisimilarity Pseudometric", "Subsubsection",
 CellChangeTimes->{{3.573197378994329*^9, 3.5731974027498302`*^9}}],

Cell[TextData[{
 "To cope with the problem of measuring how similar two MDPs are, Ferns et \
al. [",
 ButtonBox["1",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dl.acm.org/citation.cfm?id=1036843.1036863"], None},
  ButtonNote->"http://dl.acm.org/citation.cfm?id=1036843.1036863"],
 "] defined a bisimilarity pseudometric that measures the behavioral \
similarity of two non-bisimilar MDPs. This is defined as the least fixed \
point of a transformation operator on functions in S \[Times] S \[RightArrow] \
[0,\[Infinity]). \nConsider an arbitrary MDP \[ScriptCapitalM] =(S,A,\[Tau],\
\[Rho]) and a discount factor \[Lambda] \[Element] (0,1). The set S \[Times] \
S \[RightArrow] [0,\[Infinity]) of [0,\[Infinity])-valued maps on S \[Times] \
S equipped with the point-wise partial order defined by d \
\[SquareSubsetEqual] d\[CloseCurlyQuote] \[DoubleLeftRightArrow] d(s,t) \
\[LessSlantEqual] d\[CloseCurlyQuote](s,t), for all s,t \[Element] S. \nWe \
define a fixed point operator ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[ScriptCapitalF]", "\[Lambda]"], " ", ":", " ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"S", "\[Times]", "S"}], "\[RightArrow]", 
         RowBox[{"[", 
          RowBox[{"0", ",", "\[Infinity]"}]}]}], ")"}]}], " ", ")"}], " ", 
     "\[RightArrow]", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"S", "\[Times]", "S"}], "\[RightArrow]", 
       RowBox[{"[", 
        RowBox[{"0", ",", "\[Infinity]"}]}]}], ")"}]}], " ", ")"}], 
   TraditionalForm]]],
 ", for d : S \[Times] S \[RightArrow] [0,\[Infinity]) and s,t \[Element] S \
as "
}], "Text",
 CellChangeTimes->{{3.573197460795909*^9, 3.5731980924767733`*^9}, {
   3.57319932785832*^9, 3.573199327862383*^9}, 3.5734565323988132`*^9, 
   3.57389951705903*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[ScriptCapitalF]", "\[Lambda]"], "(", "d", ")"}], 
    RowBox[{"(", 
     RowBox[{"s", ",", "t"}], ")"}]}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["max", 
     RowBox[{" ", 
      RowBox[{"a", " ", "\[Element]", " ", "A"}]}]], "(", 
    RowBox[{"|", 
     RowBox[{
      RowBox[{"\[Rho]", "(", 
       RowBox[{"s", ",", "a"}], ")"}], " ", "-", " ", 
      RowBox[{"\[Rho]", "(", 
       RowBox[{"t", ",", "a"}], ")"}]}], "|", " ", 
     RowBox[{
      RowBox[{"+", " ", "\[Lambda]"}], " ", 
      RowBox[{
       SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
       RowBox[{
        RowBox[{"\[Tau]", "(", 
         RowBox[{"s", ",", "a"}], ")"}], ",", 
        RowBox[{"\[Tau]", "(", 
         RowBox[{"t", ",", "a"}], ")"}]}], ")"}]}]}], " ", ")"}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
  3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
  3.573198352674038*^9}}],

Cell[TextData[{
 "Where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
    RowBox[{
     RowBox[{"\[Tau]", "(", 
      RowBox[{"s", ",", "a"}], ")"}], ",", 
     RowBox[{"\[Tau]", "(", 
      RowBox[{"t", ",", "a"}], ")"}]}], ")"}], TraditionalForm]],
  CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
   3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
   3.573198352674038*^9}}],
 " denotes the optimal value of a Transportation Problem with marginals \
\[Tau](s,a) and \[Tau](t,a) and costs given by d"
}], "Text",
 CellChangeTimes->{{3.573198455370479*^9, 3.573198707983498*^9}, {
   3.573198830317322*^9, 3.57319883814186*^9}, {3.573455480126729*^9, 
   3.5734556037187023`*^9}, {3.573456180609993*^9, 3.573456196582041*^9}, 
   3.5738994756670847`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[ScriptCapitalT]", "d"], "(", 
    RowBox[{
     RowBox[{"\[Tau]", "(", 
      RowBox[{"s", ",", "a"}], ")"}], ",", 
     RowBox[{"\[Tau]", "(", 
      RowBox[{"t", ",", "a"}], ")"}]}], ")"}], " ", "=", " ", 
   RowBox[{"min", " ", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         UnderscriptBox["\[Sum]", 
          RowBox[{"u", ",", 
           RowBox[{"v", " ", "\[Element]", " ", "S", " "}]}]], 
         RowBox[{
          RowBox[{"d", "(", 
           RowBox[{"u", ",", "v"}], ")"}], " ", 
          RowBox[{"\[Omega]", "(", 
           RowBox[{"u", ",", "v"}], ")"}]}]}], "  ", "|", "  ", 
        RowBox[{
         UnderscriptBox["\[Sum]", 
          RowBox[{"u", " ", "\[Element]", " ", "S"}]], 
         RowBox[{"\[Omega]", "(", 
          RowBox[{"u", ",", "v"}], ")"}]}]}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Tau]", "(", 
           RowBox[{"s", ",", "a"}], ")"}], 
          RowBox[{"(", "v", ")"}]}], "   ", "\[And]", " ", 
         RowBox[{
          UnderscriptBox["\[Sum]", 
           RowBox[{"v", " ", "\[Element]", " ", "S"}]], 
          RowBox[{"\[Omega]", "(", 
           RowBox[{"u", ",", "v"}], ")"}]}]}], " ", "=", " ", 
        RowBox[{
         RowBox[{"\[Tau]", "(", 
          RowBox[{"t", ",", "a"}], ")"}], 
         RowBox[{"(", "u", ")"}]}]}]}], "}"}], " ", "."}]}]}], 
  TraditionalForm]], "DisplayFormula",
 CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
  3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
  3.573198352674038*^9}, {3.573455722484456*^9, 3.5734559069141808`*^9}, {
  3.5734559608097773`*^9, 3.573456008949929*^9}, {3.573456075258862*^9, 
  3.573456080720895*^9}, {3.5734561150715723`*^9, 3.573456146309628*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalF]", "\[Lambda]"], TraditionalForm]], 
  "DisplayFormula",
  CellChangeTimes->{{3.573198129538149*^9, 3.573198150096148*^9}, {
   3.5731982049028263`*^9, 3.5731982832918262`*^9}, {3.573198317720042*^9, 
   3.573198352674038*^9}}],
 " is monotonic, thus, by Tarski\[CloseCurlyQuote]s fixed point theorem, its \
admits a least fixed point. This fixed point is the bisimilarity pseudometric."
}], "Text",
 CellChangeTimes->{3.573455617415782*^9}],

Cell[TextData[{
 StyleBox["Definition (Bisimilarity psudometric).",
  FontWeight->"Bold"],
 " Let \[ScriptCapitalM] =(S,A,\[Tau],\[Rho]) be an MDP and \[Lambda] \
\[Element] (0,1) be a discount factor, then the \[Lambda]-discounted \
bisimilarity pseudometric for \[ScriptCapitalM], written ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", is the lest fixed point of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalF]", "\[Lambda]"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{3.573198845166564*^9}],

Cell[TextData[{
 "The pseudometric ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " enjoys the property that two states are at distance zero if and only if \
they are bisimilar."
}], "Text",
 CellChangeTimes->{{3.573198849060852*^9, 3.573198924857772*^9}, {
  3.57319937509787*^9, 3.573199375959075*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Getting started", "Subsection",
 CellChangeTimes->{{3.5732762115532627`*^9, 3.5732762192393208`*^9}}],

Cell["\<\
The package can be loaded by setting as current directory the directory of \
the MDPDist package, then using the commad << (Get) as follows\
\>", "Text",
 CellChangeTimes->{{3.5732762277426653`*^9, 3.573276447384153*^9}, {
  3.5732764926541557`*^9, 3.57327660344797*^9}, {3.573276634864959*^9, 
  3.5732767398435163`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "MDPDist`"}], ";"}]}], "Input",
 CellChangeTimes->{{3.57327674439852*^9, 3.573276798439444*^9}, {
  3.573276885083823*^9, 3.573276890069765*^9}, {3.573276928330451*^9, 
  3.573276934981387*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Encoding and manipulating Markov Decision Processes\
\>", "Subsection",
 CellChangeTimes->{{3.573198951089554*^9, 3.573198998076929*^9}, {
  3.573456702003488*^9, 3.573456706488525*^9}}],

Cell[CellGroupData[{

Cell["Encoding an MDP", "Subsubsection",
 CellChangeTimes->{3.573275199643621*^9}],

Cell[TextData[{
 "An MPD \[ScriptCapitalM] =(S,A,\[Tau],\[Rho]) with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"S", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["s", "1"], ",", "...", ",", " ", 
      SubscriptBox["s", "n"]}], "}"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["a", "1"], ",", "...", ",", " ", 
      SubscriptBox["a", "n"]}], "}"}]}], TraditionalForm]]],
 " is represented as a term of the form ",
 StyleBox["MPD[tm,rw,act]", "Program"],
 " where\n- ",
 StyleBox["tm", "Program"],
 " is an n \[Times] m \[Times] n probability matrix such that ",
 StyleBox["tm\[LeftDoubleBracket]i,k,j\[RightDoubleBracket]", "Program"],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Tau]", "(", 
     RowBox[{
      SubscriptBox["s", "i"], ",", 
      SubscriptBox["a", "k"]}], ")"}], 
    RowBox[{"(", 
     SubscriptBox["s", "j"], ")"}]}], TraditionalForm]], "Item"],
 " for all 1 \[LessEqual] i,j \[LessEqual] n and all 1 \[LessEqual] k \
\[LessEqual] m,\n- ",
 StyleBox["rw", "Program"],
 " is an n \[Times] m real-valued matrix such that ",
 StyleBox["rw\[LeftDoubleBracket]i,k\[RightDoubleBracket]", "Program"],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", "(", 
    RowBox[{
     SubscriptBox["s", "i"], ",", 
     SubscriptBox["a", "k"]}], ")"}], TraditionalForm]]],
 " for all 1 \[LessEqual] i \[LessEqual] n and all 1 \[LessEqual] k \
\[LessEqual] m, and\n- ",
 StyleBox["act", "Program"],
 " is a list of pairwise distinct strings such that act\[LeftDoubleBracket]k\
\[RightDoubleBracket] represents the action ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "k"], TraditionalForm]]],
 "for all 1 \[LessEqual] k \[LessEqual] m.\nA state ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "i"], TraditionalForm]]],
 " is implicitly represented by its index 1 \[LessEqual] i \[LessEqual] n."
}], "Text",
 CellChangeTimes->{{3.573199019506357*^9, 3.573199049219491*^9}, {
   3.573203010715269*^9, 3.573203203858581*^9}, {3.573203256370788*^9, 
   3.573203718983848*^9}, {3.573203801057808*^9, 3.573203977774061*^9}, 
   3.5732040156204033`*^9, {3.573204047564517*^9, 3.5732043161811123`*^9}, {
   3.5734566486328297`*^9, 3.573456667701949*^9}, {3.573457169430642*^9, 
   3.573457180178797*^9}}],

Cell[TextData[{
 "Assume we want to encode the following MDP \[ScriptCapitalM] =(S,A,\[Tau],\
\[Rho]) with S = {1,2,3,4,5,6} and A = {",
 StyleBox["inc", "Program"],
 ", ",
 StyleBox["dec", "Program"],
 "}, with the following intuitive operational behavior.  Given \
\[ScriptCapitalM] in state i, the choice of the action ",
 StyleBox["inc", "Program"],
 " causes the MDP to move in state i+1 with probability 0.8, and to stay in \
state i or to move in state i-1 both with probability 0.1. The choice of the \
action ",
 StyleBox["dec", "Program"],
 " causes the MDP to move in state i-1 with probability 0.7, to stay in state \
i with probability 0.1, and to move in state i+1 with probability 0.2. The \
reward of choising an ",
 StyleBox["inc", "Program"],
 " action is always -1, whereas the reward for a ",
 StyleBox["dec", "Program"],
 " action is 5 if it is made from state 5 or 6, 0 otherwise."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQnaAjvjtm/ivHT5rhJ0C0QMTiCyB64qXYSyD6TkXe
HRAtk7nxP4h+cKWTPRZIC/2M5wLRAXMeCoLoa48cpUB0r8sxUxB9ZzavOYj+
sPKhNYjueZWYBKLfPD+ZBqLltnTMB9F1PHd844D0l9diQSD6Q+Q2rnggfURJ
ghtEm0x1FADRb3WeyYBolZJTSiD6odo/ML3tuHIyiDbYFwWmV6mecGgF0i6S
D0NBtMyMyzpXQO7eG2IMojOcppuD6NyUrxYg+tPpSU4gWn3/Fg8QrbXjuA+I
FjqzPQpEW63fGA+ij+h7TwfRMnevzwbRaUKWc0A0AH7Bq+k=
  "]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " allows to easily define functions and lists, so that we can exploit these \
features in order to define the data structures that are needed to encode \
\[ScriptCapitalM]"
}], "Text",
 CellChangeTimes->{{3.573218087195854*^9, 3.5732181968507633`*^9}, {
  3.573295802833493*^9, 3.573295838423162*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<inc\>\"", ",", " ", "\"\<dec\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Tau]", "[", 
    RowBox[{"i_", ",", "act_", ",", "j_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Which", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"j", "-", "1"}], "\[Equal]", 
      RowBox[{"Mod", "[", 
       RowBox[{"i", ",", "6"}], "]"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"act", "\[Equal]", "\"\<inc\>\""}], ",", "0.8", ",", "0.2"}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"i", "\[Equal]", "j"}], ",", " ", "0.1", ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"j", "-", "1"}], "\[Equal]", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"i", "-", "2"}], ",", "6"}], "]"}]}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"act", "\[Equal]", "\"\<dec\>\""}], ",", "0.7", ",", "0.1"}], 
      "]"}], ",", "\[IndentingNewLine]", "True", ",", " ", "0"}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"_", ",", "\"\<inc\>\""}], "]"}], ":=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"6", ",", "\"\<dec\>\""}], "]"}], ":=", "5"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"5", ",", "\"\<dec\>\""}], "]"}], ":=", "5"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "[", 
    RowBox[{"_", ",", "\"\<dec\>\""}], "]"}], ":=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.573214464127891*^9, 3.573214771821967*^9}, {
  3.57321481191409*^9, 3.5732148159299927`*^9}, {3.573214912467607*^9, 
  3.5732149376029997`*^9}, {3.573215676823241*^9, 3.57321567906989*^9}, {
  3.5732175992554083`*^9, 3.573217720041109*^9}, {3.573294226697452*^9, 
  3.573294226791898*^9}, {3.5732944812253637`*^9, 3.5732944911847277`*^9}, {
  3.573294945666857*^9, 3.573294980834147*^9}, {3.5732954675747128`*^9, 
  3.573295548254814*^9}}],

Cell[TextData[{
 StyleBox["A", "Program"],
 " represents the set of actions, \[Tau] is the transition function and \
\[Rho] is the reward function. \nOne can obtain the respective transition and \
reward matrix using the built-in function ",
 StyleBox["Table", "Program"],
 " as follows:"
}], "Text",
 CellChangeTimes->{{3.573217761374517*^9, 3.5732178979394484`*^9}, {
  3.573218221457078*^9, 3.573218233472453*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tm", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"\[Tau]", "[", 
     RowBox[{"i", ",", "act", ",", "j"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"act", ",", "A"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"rw", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"\[Rho]", "[", 
     RowBox[{"i", ",", "act"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"act", ",", "A"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.573214947167602*^9, 3.5732149507059937`*^9}, {
   3.57321530433661*^9, 3.573215305406084*^9}, {3.573215368473428*^9, 
   3.573215457444313*^9}, {3.573215552137491*^9, 3.573215573927249*^9}, {
   3.573215624884157*^9, 3.573215625242831*^9}, 3.573215671374652*^9, {
   3.5732157188501453`*^9, 3.5732157224627113`*^9}, {3.5732157537803307`*^9, 
   3.5732158103044767`*^9}, {3.5732168197306147`*^9, 3.573216876194726*^9}, {
   3.57321696973943*^9, 3.5732169814929647`*^9}, {3.573217182544003*^9, 
   3.5732171858386*^9}, {3.573217266134767*^9, 3.573217268598529*^9}, {
   3.573217324262936*^9, 3.573217328758007*^9}, {3.573217568303362*^9, 
   3.573217570647407*^9}, {3.573217901996628*^9, 3.5732179633069477`*^9}, {
   3.573218287800211*^9, 3.57321828942942*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.1`", ",", "0.8`", ",", "0", ",", "0", ",", "0", ",", "0.1`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.1`", ",", "0.2`", ",", "0", ",", "0", ",", "0", ",", "0.7`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.1`", ",", "0.1`", ",", "0.8`", ",", "0", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.7`", ",", "0.1`", ",", "0.2`", ",", "0", ",", "0", ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0.1`", ",", "0.1`", ",", "0.8`", ",", "0", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0.7`", ",", "0.1`", ",", "0.2`", ",", "0", ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0.1`", ",", "0.1`", ",", "0.8`", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0.7`", ",", "0.1`", ",", "0.2`", ",", "0"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0.1`", ",", "0.1`", ",", "0.8`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0", ",", "0", ",", "0", ",", "0.7`", ",", "0.1`", ",", "0.2`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.8`", ",", "0", ",", "0", ",", "0", ",", "0.1`", ",", "0.1`"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "0.2`", ",", "0", ",", "0", ",", "0", ",", "0.7`", ",", "0.1`"}], 
      "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.573218290064972*^9, 3.5732769885461884`*^9, 3.573277160261096*^9, 
   3.5732945005712633`*^9, {3.573294971805541*^9, 3.5732949835250072`*^9}, 
   3.573295555598378*^9, 3.573454615034494*^9, 3.576236413709635*^9, 
   3.576296947383909*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.573218290064972*^9, 3.5732769885461884`*^9, 3.573277160261096*^9, 
   3.5732945005712633`*^9, {3.573294971805541*^9, 3.5732949835250072`*^9}, 
   3.573295555598378*^9, 3.573454615034494*^9, 3.576236413709635*^9, 
   3.576296947386195*^9}]
}, Open  ]],

Cell["Then \[ScriptCapitalM] is encoded by", "Text",
 CellChangeTimes->{{3.573217976417899*^9, 3.573218023999145*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mdp", "=", 
   RowBox[{"MDP", "[", 
    RowBox[{"tm", ",", "rw", ",", "A"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.573218026215323*^9, 3.573218046374742*^9}}],

Cell[TextData[{
 "Alternatively, one may use the functions ",
 StyleBox["MDPtm", "Program"],
 " and ",
 StyleBox["MDPrw", "Program"],
 " to construct the transition and the reward matrices listing only the \
values different from zero. Given the list of rules ",
 StyleBox["tmRules", "Program"],
 " = { ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "k"}], "}"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Tau]", "(", 
         RowBox[{
          SubscriptBox["s", "i"], ",", 
          SubscriptBox["a", "k"]}], ")"}], 
        RowBox[{"(", 
         SubscriptBox["s", "j"], ")"}]}], ":", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Tau]", "(", 
          RowBox[{
           SubscriptBox["s", "i"], ",", 
           SubscriptBox["a", "k"]}], ")"}], 
         RowBox[{"(", 
          SubscriptBox["s", "j"], ")"}]}], " ", "\[NotEqual]", " ", "0"}]}]}],
      ",", " ", 
     RowBox[{"1", " ", "\[LessEqual]", " ", "i"}], ",", 
     RowBox[{"j", " ", "\[LessEqual]", "n"}], " ", ",", " ", 
     RowBox[{
     "1", " ", "\[LessEqual]", " ", "k", " ", "\[LessEqual]", " ", "m"}]}], 
    "}"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", the probabilty transition matrix induced by the probability transition \
function \[Tau] may be constructed by calling ",
 StyleBox["MDPtm[tmRules, n, m]", "Program"],
 ". \nAnalogously, for ",
 StyleBox["rwRules", "Program"],
 " = { ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "k"}], "}"}], "\[Rule]", " ", 
      RowBox[{
       RowBox[{"\[Rho]", "(", 
        RowBox[{
         SubscriptBox["s", "i"], ",", 
         SubscriptBox["a", "k"]}], ")"}], ":", " ", 
       RowBox[{
        RowBox[{"\[Rho]", "(", 
         RowBox[{
          SubscriptBox["s", "i"], ",", 
          SubscriptBox["a", "k"]}], ")"}], " ", "\[NotEqual]", " ", "0"}]}]}],
      ",", " ", 
     RowBox[{"1", " ", "\[LessEqual]", " ", "i", "\[LessEqual]", "n"}], " ", 
     ",", " ", 
     RowBox[{
     "1", " ", "\[LessEqual]", " ", "k", " ", "\[LessEqual]", " ", "m"}]}], 
    "}"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", one can construct the reward matrix induced by the reward function \[Rho] \
by calling ",
 StyleBox["MDPrw[rwRules, n, m]", "Program"],
 ". "
}], "Text",
 CellChangeTimes->{{3.5732183557821093`*^9, 3.5732185541642847`*^9}, {
  3.573221420509203*^9, 3.573221655032852*^9}, {3.573221694361526*^9, 
  3.573221993064777*^9}, {3.573459075932345*^9, 3.573459134486761*^9}, {
  3.573459169230999*^9, 3.573459173310443*^9}, {3.57345920764123*^9, 
  3.573459231552876*^9}, {3.573459266326976*^9, 3.573459305986116*^9}, {
  3.573459343315477*^9, 3.573459355034486*^9}, {3.5734594476651773`*^9, 
  3.5734595474914913`*^9}, {3.573459590298663*^9, 3.573459616088747*^9}}],

Cell[TextData[{
 "The list of rules may be given explicitly or using patterns. For example, \
the matrices ",
 StyleBox["tm", "Program"],
 " and ",
 StyleBox["rw", "Program"],
 " defined above can be constructed as follows"
}], "Text",
 CellChangeTimes->{{3.5732185584691668`*^9, 3.573218775344339*^9}, 
   3.573221870313819*^9, {3.573222002024242*^9, 3.573222148536551*^9}, {
   3.573222180302464*^9, 3.573222210164556*^9}, {3.573459771157456*^9, 
   3.5734597827794743`*^9}, {3.573460912446989*^9, 3.573460941284193*^9}, {
   3.573899744501182*^9, 3.573899745306484*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tm", "=", 
   RowBox[{
    StyleBox["MDPtm",
     FontSlant->"Italic"], "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "1", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{"i", ",", "6"}], "]"}]}]}], ")"}], "\[Rule]", " ", 
        "0.8"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "1", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "-", "2"}], ",", "6"}], "]"}]}]}], ")"}], "\[Rule]",
         " ", "0.1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i_", ",", "_", ",", "i_"}], "}"}], "\[Rule]", "0.1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "2", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "-", "2"}], ",", "6"}], "]"}]}]}], ")"}], "\[Rule]",
         " ", "0.7"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "2", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{"i", ",", "6"}], "]"}]}]}], ")"}], "\[Rule]", " ", 
        "0.2"}]}], "\[IndentingNewLine]", "}"}], ",", "6", ",", "2"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rw", " ", "=", " ", 
   RowBox[{"MDPrw", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"_", ",", "1"}], "}"}], "\[Rule]", " ", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"6", "|", "5"}], ",", "2"}], "}"}], "\[Rule]", "5"}]}], 
      "}"}], ",", "6", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mdp", "=", 
   RowBox[{"MDP", "[", 
    RowBox[{"tm", ",", "rw", ",", "A"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5732188405023413`*^9, 3.573218917503303*^9}, {
  3.573218977692976*^9, 3.57321939384553*^9}, {3.573219470805388*^9, 
  3.573219502430997*^9}, {3.573219552581006*^9, 3.573219655008902*^9}, {
  3.573222195440791*^9, 3.573222197552487*^9}, {3.573294237554175*^9, 
  3.57329423767317*^9}, {3.573294394866943*^9, 3.573294396569407*^9}, {
  3.5732945282881327`*^9, 3.5732945827830067`*^9}, {3.5732946852238827`*^9, 
  3.573294705037438*^9}, {3.5732948723236322`*^9, 3.573294876553846*^9}, {
  3.573295004978117*^9, 3.5732950098880987`*^9}, {3.573454404790081*^9, 
  3.5734544053066063`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Manipulating MDPs", "Subsubsection",
 CellChangeTimes->{{3.5732222543867693`*^9, 3.573222265168182*^9}}],

Cell[TextData[{
 "An MDP is dispayed by the function ",
 StyleBox["PlotMDP", "Program"],
 ". States are represented as white nodes labeled with their respective \
index. Red edges exiting from each node represent a nondeterministic choice \
of an action. The chosen action is displayed as a colored node labeled with \
its associated reward, called choice node. Edges exiting form a choice node \
represent the probability distribution obtained after a nondeterministic \
choice. For example, the MDP ",
 StyleBox["mdp", "Program"],
 " defined above is dispayed as follows"
}], "Text",
 CellChangeTimes->{{3.573222276856881*^9, 3.573222412533598*^9}, {
  3.5732959722767153`*^9, 3.573296143266732*^9}, {3.573296185879876*^9, 
  3.573296449692474*^9}, {3.5734598044038153`*^9, 3.573459843136808*^9}, {
  3.57345991196036*^9, 3.573460126521899*^9}, {3.573460982666903*^9, 
  3.573461006150261*^9}, {3.5734610655510607`*^9, 3.5734610668615828`*^9}, {
  3.573461131211405*^9, 3.57346119492929*^9}, {3.5734614050099907`*^9, 
  3.573461405374761*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotMDP", "[", "mdp", "]"}]], "Input",
 CellChangeTimes->{{3.573222357298649*^9, 3.573222367273797*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5582488835898263, 1.2931217454454353`}, {
       0.520235465277479, 1.2148523854822386`}, {0.5110248603945788, 
       1.1973845143025004`}, {0.5006783069954961, 1.1805645678513146`}, {
       0.48924118010669443`, 1.1644663103558497`}, {0.4767636374875006, 
       1.149160341061256}, {0.4633003996622005, 1.1347137846161983`}, {
       0.4489105099420352, 1.1211899966963026`}, {0.4336570754895235, 
       1.1086482861565172`}, {0.2103575220535931, 0.9371168582499365}, {
       0.19430743712474974`, 0.9256122270243059}, {0.17753108970292586`, 
       0.9151951289138389}, {0.16010205281083442`, 0.9059112483203072}, {
       0.14209676185452005`, 0.8978012998963467}, {0.12359417941428566`, 
       0.8909008499904953}, {0.10467544895264419`, 0.8852401606702274}, {
       0.08542353895796563, 0.8808440570070238}, {0., 0.8642931756789836}}], 
       0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5582488835898263, 1.2931217454454353`}, {
       0.5636834251409828, 1.1994368092930783`}, {0.5642121064311159, 
       1.178145785207962}, {0.5633304404422561, 1.156866455435067}, {
       0.5610422937390487, 1.1356921409204448`}, {0.5573577010367472, 
       1.1147157020635348`}, {0.5522928211937583, 1.0940291314759378`}, {
       0.5458698663466313, 1.0737231505458942`}, {0.5381170044982675, 
       1.0538868115777347`}, {0.41826477604131673`, 0.7748576425731171}, {
       0.40921600752960363`, 0.7555779382465211}, {0.39891101591822176`, 
       0.7369394201082976}, {0.3873949939635452, 0.719023827769808}, {
       0.3747184454208632, 0.7019097304361898}, {0.36093696355910376`, 
       0.6856721823394624}, {0.34611098735539014`, 0.670382393586623}, {
       0.3303055364386411, 0.6561074178662313}, {0.25861831244744926`, 
       0.5955488229338917}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {0.03801341831234736,
        0.9425625356421804}, {0.04722402319524746, 0.9600304068219188}, {
       0.05757057659433029, 0.9768503532731048}, {0.06900770348313195, 
       0.9929486107685696}, {0.0814852461023258, 1.0082545800631628`}, {
       0.09494848392762589, 1.0227011365082208`}, {0.1093383736477912, 
       1.0362249244281165`}, {0.12459180810030288`, 1.048766634967902}, {
       0.34789136153623323`, 1.2202980628744826`}, {0.3639414464650766, 
       1.231802694100113}, {0.38071779388690047`, 1.2422197922105802`}, {
       0.3981468307789919, 1.251503672804112}, {0.41615212173530625`, 
       1.2596136212280724`}, {0.4346547041755407, 1.2665140711339238`}, {
       0.4535734346371821, 1.2721747604541918`}, {0.4728253446318607, 
       1.2765708641173952`}, {0.5582488835898263, 1.2931217454454353`}}], 
       0.1], InsetBox["0.1`", {0.24712953082222336`, 1.1203584245844704`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.8`", {0.50210078094351, 0.44253347301398827`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.33071258057130426`, 1.296399370059101},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       0.25318377089629274`, 0.6892337590862491}, {0.2526550896061596, 
       0.7105247831713654}, {0.2535367555950195, 0.7318041129442606}, {
       0.2558249022982268, 0.7529784274588827}, {0.2595094950005284, 
       0.7739548663157927}, {0.26457437484351715`, 0.7946414369033894}, {
       0.27099732969064416`, 0.8149474178334332}, {0.2787501915390081, 
       0.8347837568015926}, {0.39860241999595886`, 1.1138129258062102`}, {
       0.4076511885076719, 1.1330926301328061`}, {0.41795618011905383`, 
       1.1517311482710297`}, {0.4294722020737304, 1.169646740609519}, {
       0.4421487506164124, 1.1867608379431374`}, {0.4559302324781719, 
       1.2029983860398648`}, {0.4707562086818855, 1.2182881747927041`}, {
       0.4865616595986345, 1.2325631505130958`}, {0.5582488835898263, 
       1.2931217454454353`}}], 0.1], 
      InsetBox["0.1`", {0.35638766375434394`, 0.9666907290557032},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       1.00420156188702, 0.02077377034899297}}], 0.1], 
      InsetBox["0.2`", {0.6314099371672346, 0.3081612966414423},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.7`", {0.4600217367950289, 1.162027193686555},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.00420156188702, 0.02077377034899297}, {
       0.990398363857955, 0.1051730642369664}, {0.9879016743420681, 
       0.1244207506139478}, {0.9866844051792294, 0.1437914796965244}, {
       0.9867518947288277, 0.1632003007469146}, {0.9881038470140309, 
       0.1825620959742149}, {0.9907343330197982, 0.2017919538202531}, {
       0.9946318166947008, 0.22080554134100366`}, {0.9997792055425163, 
       0.23951947405047874`}, {1.0819706594097063`, 0.5037832610300628}, {
       1.088345379448918, 0.5221154685847205}, {1.095919474211384, 
       0.5399855547046741}, {1.1046597273460133`, 0.5573151497532601}, {
       1.1145278082897683`, 0.5740282544287199}, {1.1254804403671512`, 
       0.590051573060728}, {1.1374695905809704`, 0.6053148350500883}, {
       1.150442680262055, 0.6197511030419176}, {1.2096801965549946`, 
       0.6814332377979534}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.00420156188702, 0.02077377034899297}, {
       1.0222239503085737`, 0.07096423098511406}, {1.0266890640500914`, 
       0.08221330263881006}, {1.0318889286420436`, 0.09314217550018217}, {
       1.0378007399694402`, 0.1037029207685778}, {1.0443985716599828`, 
       0.11384922407460757`}, {1.0516534887847129`, 0.12353658859278142`}, {
       1.0595336747527495`, 0.13272253018326807`}, {1.0680045708436139`, 
       0.1413667637069795}, {1.192805378934721, 0.2605571521539257}, {
       1.2018298358563277`, 0.2686217681438374}, {1.2113682766639837`, 
       0.2760713990577498}, {1.221378870325907, 0.2828733743833841}, {
       1.2318177151740917`, 0.2889978639155984}, {1.2426390314359925`, 
       0.29441800857737616`}, {1.2537953620026747`, 0.2991100382108704}, {
       1.2652377805529587`, 0.303053375821929}, {1.3162035821147877`, 
       0.3187497414663586}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.1`", {0.8839645400724104, 0.9872774916216944},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       1.2234833945840595`, 0.5970339439099801}, {1.2259800840999464`, 
       0.5777862575329986}, {1.2271973532627851`, 0.5584155284504221}, {
       1.2271298637131869`, 0.5390067074000319}, {1.2257779114279839`, 
       0.5196449121727316}, {1.2231474254222165`, 0.5004150543266933}, {
       1.2192499417473137`, 0.4814014668059428}, {1.2141025528994984`, 
       0.4626875340964678}, {1.1319110990323085`, 0.19842374711688365`}, {
       1.1255363789930968`, 0.18009153956222596`}, {1.1179622842306307`, 
       0.1622214534422723}, {1.1092220310960013`, 0.1448918583936863}, {
       1.0993539501522465`, 0.1281787537182265}, {1.0884013180748635`, 
       0.1121554350862184}, {1.076412167861044, 0.09689217309685808}, {
       1.0634390781799596`, 0.08245590510502881}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.1562326996232866`, 0.3357727376868675},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.8`", {1.7430632354645732`, 0.6974958712780831},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.7`", {0.937226232852307, 0.8059357434558969},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       1.2981811936932344`, 0.2685592808302375}, {1.2937160799517167`, 
       0.25731020917654157`}, {1.2885162153597642`, 0.24638133631516945`}, {
       1.2826044040323679`, 0.23582059104677378`}, {1.2760065723418252`, 
       0.22567428774074402`}, {1.2687516552170952`, 0.21598692322257018`}, {
       1.2608714692490586`, 0.20680098163208355`}, {1.2524005731581942`, 
       0.1981567481083721}, {1.127599765067087, 0.07896635966142593}, {
       1.1185753081454803`, 0.0709017436715142}, {1.1090368673378244`, 
       0.06345211275760185}, {1.099026273675901, 0.056650137431967534`}, {
       1.0885874288277164`, 0.05052564789975322}, {1.0777661125658156`, 
       0.04510550323797548}, {1.0666097819991334`, 0.040413473604481207`}, {
       1.0551673634488492`, 0.03647013599342265}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.1824345671151595`, 0.14648327689699922`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.2`", {1.7963249282444698`, 0.5161541231122857},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.276446274374152, 0.7135585047582128}, {
       2.2841610491412485`, 0.6188045320803315}, {2.2851989132611186`, 
       0.5972538873772305}, {2.284808130088413, 0.5756818050122261}, {
       2.282990413410913, 0.5541828898039896}, {2.279753734863149, 
       0.5328514256950951}, {2.2751122889666298`, 0.5117809622678164}, {
       2.26908643087947, 0.49106390448047543`}, {2.2617025871284206`, 
       0.47079110742356467`}, {2.1469032034996838`, 0.18536770552027962`}, {
       2.138193756086043, 0.1656280759695602}, {2.1281969004737147`, 
       0.1465081824835372}, {2.1169564780822, 0.1280918757552338}, {
       2.1045217840191373`, 0.11045992088322285`}, {2.0909473508955716`, 
       0.09368964317459637}, {2.0762927096720523`, 0.07785458903321328}, {
       2.0606221285843564`, 0.063024203420406}, {1.9894478153023094`, 0.}}], 
       0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.276446274374152, 0.7135585047582128}, {
       2.3222629488192945`, 0.6420261852523458}, {2.332117820594771, 
       0.6254564922706586}, {2.3408543855086794`, 0.6082708687229512}, {
       2.3484343291727514`, 0.5905446825209523}, {2.3548244095854165`, 
       0.5723556722252234}, {2.3599966029152917`, 0.5537836061210756}, {
       2.3639282264002874`, 0.5349099323930839}, {2.366602037823328, 
       0.5158174219323701}, {2.3956925208320023`, 0.2424658171616885}, {
       2.397096794137135, 0.22323820057244528`}, {2.397225370854392, 
       0.20395980096961963`}, {2.396077687107888, 0.1847151641781273}, {
       2.3936587760887122`, 0.1655886879553684}, {2.3899792459817633`, 
       0.14666425186309603`}, {2.385055233443328, 0.1280248494118427}, {
       2.3789083328334457`, 0.10975222409114303`}, {2.3491724818958377`, 
       0.03017949283150867}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.4968246885946646`, 0.010386885174496485`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {
       1.9817330405352127`, 0.09475397267788135}, {1.9806951764153424`, 
       0.11630461738098231`}, {1.9810859595880486`, 0.13787669974598676`}, {
       1.9829036762655488`, 0.15937561495422334`}, {1.9861403548133127`, 
       0.1807070790631178}, {1.990781800709832, 0.20177754249039656`}, {
       1.9968076587969914`, 0.22249460027773743`}, {2.004191502548041, 
       0.24276739733464825`}, {2.118990886176778, 0.5281907992379332}, {
       2.1277003335904183`, 0.5479304287886526}, {2.137697189202747, 
       0.5670503222746757}, {2.148937611594261, 0.5854666290029791}, {
       2.161372305657324, 0.60309858387499}, {2.17494673878089, 
       0.6198688615836165}, {2.1896013800044094`, 0.6357039157249995}, {
       2.2052719610921048`, 0.6505343013378069}, {2.276446274374152, 
       0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.0797084258582066`, 0.3781922150282689},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.8`", {2.182744845405451, 0.5659628920244686},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       1.00420156188702, 0.02077377034899297}}], 0.1], 
      InsetBox["0.7`", {1.676687021891429, 0.02547663159025082},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       2.303355807450695, 0.10171181233737585`}, {2.293500935675219, 
       0.11828150531906301`}, {2.28476437076131, 0.13546712886677037`}, {
       2.277184427097238, 0.15319331506876935`}, {2.270794346684573, 
       0.17138232536449816`}, {2.265622153354698, 0.189954391468646}, {
       2.2616905298697025`, 0.20882806519663769`}, {2.2590167184466616`, 
       0.22792057565735152`}, {2.229926235437987, 0.501272180428033}, {
       2.228521962132854, 0.5204997970172762}, {2.2283933854155977`, 
       0.5397781966201018}, {2.229541069162102, 0.5590228334115942}, {
       2.2319599801812773`, 0.5781493096343531}, {2.2356395102882263`, 
       0.5970737457266255}, {2.240563522826661, 0.6157131481778788}, {
       2.246710423436544, 0.6339857734985785}, {2.276446274374152, 
       0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.2618224519161854`, 0.366442894521293},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.2`", {2.3626071787022154`, 0.5810526384402229},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3760418755085926`, 1.1319257840489372`}, {
       2.408252451906797, 1.2131184852349586`}, {2.416168789048424, 
       1.2312930530189958`}, {2.4252706868202054`, 1.2489038100960925`}, {
       2.435518228658978, 1.2658735241225303`}, {2.4468664737555486`, 
       1.282127774062304}, {2.45926565414355, 1.297595276562135}, {
       2.472661392957901, 1.3122081985661067`}, {2.486994942905686, 
       1.3259024547989517`}, {2.6977292920822036`, 1.5142932327401317`}, {
       2.712937793080154, 1.5270087667545489`}, {2.7289545479288617`, 
       1.5386898143100072`}, {2.7457093148147385`, 1.5492851479279917`}, {
       2.7631286153569636`, 1.558748301551182}, {2.7811360568484593`, 
       1.5670377743213193`}, {2.7996526672777047`, 1.5741172125820881`}, {
       2.818597241662147, 1.579955569308838}, {2.9028777484498867`, 
       1.6029027289018873`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3760418755085926`, 1.1319257840489372`}, {
       2.3651348133550316`, 1.226185042462109}, {2.363369137628658, 
       1.2476474621648885`}, {2.3630278657674384`, 1.2691796846183578`}, {
       2.3641124944262635`, 1.2906872798103222`}, {2.3666182669434495`, 
       1.3120759257319572`}, {2.370534194201183, 1.3332518220289522`}, {
       2.3758431028185214`, 1.3541221013649292`}, {2.38252171046562, 
       1.3745952366930871`}, {2.487365293471712, 1.6632066458832557`}, {
       2.4953843109749636`, 1.6831928518401524`}, {2.504708570765287, 
       1.7026044785012933`}, {2.5152971811062335`, 1.72135639577171}, {
       2.527103705425555, 1.739366366725774}, {2.540076365963763, 
       1.7565554082589536`}, {2.554158270846575, 1.7728481374698744`}, {
       2.5692876635854223`, 1.7881731022536076`}, {2.6381508330238224`, 
       1.8534543070243594`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.5896620114120195`, 1.15823061683005},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       2.8706671720516828`, 1.5217100277158662`}, {2.862750834910056, 
       1.503535459931829}, {2.8536489371382743`, 1.4859247028547322`}, {
       2.8434013952995016`, 1.4689549888282945`}, {2.832053150202931, 
       1.4527007388885207`}, {2.81965396981493, 1.4372332363886897`}, {
       2.806258231000579, 1.422620314384718}, {2.7919246810527936`, 
       1.408926058151873}, {2.581190331876276, 1.220535280210693}, {
       2.5659818308783255`, 1.2078197461962759`}, {2.549965076029618, 
       1.1961386986408176`}, {2.5332103091437412`, 1.185543365022833}, {
       2.515791008601516, 1.1760802113996427`}, {2.4977835671100204`, 
       1.1677907386295054`}, {2.479266956680775, 1.1607113003687366`}, {
       2.4603223822963325`, 1.1548729436419867`}, {2.3760418755085926`, 
       1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.674599414335879, 1.3281070180114356`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.8`", {2.3807483562119076`, 2.0238402956578208`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.7`", {2.457298553698987, 1.2835064058912862`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       2.6490578951773838`, 1.759195048611188}, {2.6508235709037575`, 
       1.7377326289084085`}, {2.651164842764977, 1.7162004064549392`}, {
       2.650080214106152, 1.6946928112629749`}, {2.647574441588966, 
       1.6733041653413399`}, {2.6436585143312326`, 1.6521282690443448`}, {
       2.638349605713894, 1.6312579897083679`}, {2.6316709980667956`, 
       1.61078485438021}, {2.5268274150607035`, 1.3221734451900413`}, {
       2.518808397557452, 1.3021872392331446`}, {2.5094841377671284`, 
       1.2827756125720038`}, {2.498895527426182, 1.264023695301587}, {
       2.48708900310686, 1.246013724347523}, {2.4741163425686525`, 
       1.2288246828143434`}, {2.4600344376858403`, 1.2125319536034227`}, {
       2.444905044946993, 1.1972069888196895`}, {2.3760418755085926`, 
       1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.5609296165169657`, 1.4731340892592686`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.2`", {2.248384898498876, 2.149116084719057},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.858618963973929, 2.4447778624137544`}, {
       1.8818342107669963`, 2.397672222456342}, {1.8867460489304835`, 
       2.3868129799929614`}, {1.8909283764403708`, 2.3756524496461173`}, {
       1.8943628516118356`, 2.3642395761552137`}, {1.8970344124821372`, 
       2.3526244109157926`}, {1.8989313428651686`, 2.340857892478093}, {
       1.9000453237330357`, 2.3289916231549737`}, {1.9003714696993297`, 
       2.3170776427188873`}, {1.8993943886918638`, 2.1471363767948857`}, {
       1.8989312694366236`, 2.13522693425637}, {1.8976809159790353`, 
       2.1233742587249176`}, {1.8956488117703543`, 2.1116303303571256`}, {
       1.8928438686461158`, 2.1000466523966255`}, {1.889278387743093, 
       2.088674025305537}, {1.8849680055524038`, 2.0775623239779737`}, {
       1.8799316253453537`, 2.0667602790126525`}, {1.8561762614552637`, 
       2.0199246976037513`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.858618963973929, 2.4447778624137544`}, {
       1.859507836366445, 2.3581157888294078`}, {1.8590582161414022`, 
       2.338451892352433}, {1.8573080884365558`, 2.3188608730828624`}, {
       1.8542651284735818`, 2.299428647845703}, {1.8499426812170805`, 
       2.2802404370714093`}, {1.8443597028499557`, 2.2613803910599017`}, {
       1.8375406776406766`, 2.242931220937667}, {1.8295155105670067`, 
       2.2249738359263787`}, {1.70666975588375, 1.9728503855042967`}, {
       1.6974736414838414`, 1.9554635380917338`}, {1.6871469095098508`, 
       1.9387234786610947`}, {1.6757348480609675`, 1.9227036210933486`}, {
       1.663287504971507, 1.9074742208091218`}, {1.6498594683250853`, 
       1.8931020666620806`}, {1.635509627057437, 1.8796501880350167`}, {
       1.6203009126977541`, 1.86717757842317}, {1.551504577265786, 
       1.8144692363585486`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.1161090684819284`, 1.5759252408263442`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       1.8329610146621964`, 2.0670303375611643`}, {1.8280491764987092`, 
       2.0778895800245447`}, {1.823866848988822, 2.0890501103713888`}, {
       1.8204323738173571`, 2.1004629838622924`}, {1.8177608129470555`, 
       2.1120781491017135`}, {1.815863882564024, 2.123844667539413}, {
       1.814749901696157, 2.1357109368625324`}, {1.814423755729863, 
       2.147624917298619}, {1.8154008367373293`, 2.3175661832226204`}, {
       1.8158639559925696`, 2.329475625761136}, {1.8171143094501578`, 
       2.3413283012925885`}, {1.819146413658839, 2.3530722296603805`}, {
       1.8219513567830774`, 2.3646559076208806`}, {1.8255168376861002`, 
       2.376028534711969}, {1.8298272198767893`, 2.3871402360395324`}, {
       1.8348636000838394`, 2.3979422810048536`}, {1.858618963973929, 
       2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.8256993068112264`, 2.2325335301085074`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.8`", {1.2588007112989361`, 1.8742151310214847`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.7`", {1.9637732263871892`, 1.473197510203743},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       1.5506157048732705`, 1.9011313099428957`}, {1.5510653250983133`, 
       1.9207952064198708`}, {1.5528154528031597`, 1.9403862256894413`}, {
       1.5558584127661337`, 1.9598184509266008`}, {1.560180860022635, 
       1.9790066617008946`}, {1.5657638383897599`, 1.9978667077124017`}, {
       1.5725828635990389`, 2.016315877834637}, {1.5806080306727086`, 
       2.0342732628459252`}, {1.7034537853559657`, 2.2863967132680068`}, {
       1.7126498997558741`, 2.3037835606805697`}, {1.7229766317298647`, 
       2.3205236201112087`}, {1.734388693178748, 2.336543477678955}, {
       1.7468360362682085`, 2.3517728779631817`}, {1.7602640729146302`, 
       2.366145032110223}, {1.7746139141822785`, 2.3795969107372867`}, {
       1.7898226285419614`, 2.392069520349134}, {1.858618963973929, 
       2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.6580344272995702`, 2.152537361930196},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.2`", {1.1064648692041974`, 1.7714874003988834`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.6614251611426085, 1.7285055644392184`}, {
       0.6111998990987786, 1.7969807663185913`}, {0.6003220714321695, 
       1.812890154569963}, {0.590521090166301, 1.8294846276108108`}, {
       0.581839937709629, 1.8466914100323255`}, {0.574316685437931, 
       1.8644350411300947`}, {0.567984326731491, 1.882637705838601}, {
       0.5628706322819392, 1.9012195759908208`}, {0.5589980283033038, 
       1.9200991604063207`}, {0.5127229072829786, 2.190982328702565}, {
       0.5101083771610531, 2.2100768305687795`}, {0.5087633869724042, 
       2.2293025105481656`}, {0.508693835199652, 2.2485750540188194`}, {
       0.5099000268635516, 2.2678099408380152`}, {0.5123766721853179, 
       2.2869228160070603`}, {0.5161129097850611, 2.3058298596119076`}, {
       0.5210923543145956, 2.324448154417142}, {0.5457373585917956, 
       2.4057134851798287`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.6614251611426085, 1.7285055644392184`}, {
       0.6498832966371474, 1.8214906315925277`}, {0.6479640560257307, 
       1.8426688018601867`}, {0.6474507424065128, 1.8639275621612668`}, {
       0.6483456069271136, 1.8851736817575657`}, {0.6506447251404501, 
       1.9063139853469553`}, {0.654338014215482, 1.9272557616856214`}, {
       0.6594092771556777, 1.9479071701751618`}, {0.6658362738312817, 
       1.9681776436314538`}, {0.7669984407345833, 2.2540196935866663`}, {
       0.7747529854171711, 2.2738203354241477`}, {0.7838010703887499, 
       2.293064309513653}, {0.7941030150833192, 2.3116672210040754`}, {
       0.8056136401068223, 2.329547486437753}, {0.8182824653723245, 
       2.346626691536429}, {0.8320539314814914, 2.36282993508871}, {
       0.8468676433814926, 2.3780861574308965`}, {0.9143305784008628, 
       2.4431106893272503`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.8`", {0.5519931210908109, 1.849417615312632},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.2021781612828624`, 2.4252456737967916`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       0.5959626206356257, 2.337238283300456}, {0.6068404483022347, 
       2.3213288950490845`}, {0.6166414295681033, 2.3047344220082366`}, {
       0.6253225820247752, 2.287527639586722}, {0.6328458342964732, 
       2.269784008488953}, {0.6391781930029133, 2.251581343780447}, {
       0.644291887452465, 2.2329994736282273`}, {0.6481644914311006, 
       2.214119889212727}, {0.6944396124514257, 1.943236720916483}, {
       0.6970541425733512, 1.9241422190502684`}, {0.6983991327620003, 
       1.9049165390708822`}, {0.6984686845347523, 1.8856439956002287`}, {
       0.6972624928708526, 1.866409108781033}, {0.6947858475490865, 
       1.8472962336119878`}, {0.6910496099493433, 1.8283891900071407`}, {
       0.6860701654198087, 1.8097708952019063`}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.6541077608088175, 2.0757409948285463`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.2`", {0.7362897309953446, 1.8681162173863428`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.7`", {1.386474771187396, 2.4439442758705026`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       0.9258724429063241, 2.350125622173941}, {0.9277916835177409, 
       2.328947451906282}, {0.9283049971369586, 2.3076886916052017`}, {
       0.927410132616358, 2.2864425720089034`}, {0.9251110144030213, 
       2.2653022684195134`}, {0.9214177253279895, 2.244360492080847}, {
       0.9163464623877937, 2.2237090835913067`}, {0.9099194657121898, 
       2.203438610135015}, {0.808757298808888, 1.9175965601798026`}, {
       0.8010027541263004, 1.8977959183423214`}, {0.7919546691547217, 
       1.878551944252816}, {0.7816527244601523, 1.8599490327623935`}, {
       0.7701420994366492, 1.8420687673287157`}, {0.757473274171147, 
       1.8249895622300398`}, {0.7437018080619802, 1.808786318677759}, {
       0.728888096161979, 1.7935300963355727`}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.8411945771074257, 2.066938846988717},
       Background->GrayLevel[1]]}}, {
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.5582488835898263, 1.2931217454454353`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["1", {0.5582488835898263, 1.2931217454454353`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0., 0.8642931756789836}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0., 0.8642931756789836}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.25861831244744926`, 0.5955488229338917}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["0", {0.25861831244744926`, 0.5955488229338917}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.00420156188702, 0.02077377034899297}, 0.1], 
      {GrayLevel[0], InsetBox["2", {1.00420156188702, 0.02077377034899297}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.2096801965549946`, 0.6814332377979534}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.2096801965549946`, 0.6814332377979534}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.3162035821147877`, 0.3187497414663586}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["0", {1.3162035821147877`, 0.3187497414663586}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.276446274374152, 0.7135585047582128}, 0.1], 
      {GrayLevel[0], InsetBox["3", {2.276446274374152, 0.7135585047582128}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.9894478153023094`, 0.}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.9894478153023094`, 0.}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.3491724818958377`, 0.03017949283150867}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["0", {2.3491724818958377`, 0.03017949283150867}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.3760418755085926`, 1.1319257840489372`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["4", {2.3760418755085926`, 1.1319257840489372`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.9028777484498867`, 1.6029027289018873`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.9028777484498867`, 1.6029027289018873`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.6381508330238224`, 1.8534543070243594`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["0", {2.6381508330238224`, 1.8534543070243594`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.858618963973929, 2.4447778624137544`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["5", {1.858618963973929, 2.4447778624137544`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.8561762614552637`, 2.0199246976037513`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.8561762614552637`, 2.0199246976037513`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.551504577265786, 1.8144692363585486`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {1.551504577265786, 1.8144692363585486`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.6614251611426085, 1.7285055644392184`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["6", {0.6614251611426085, 1.7285055644392184`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.5457373585917956, 2.4057134851798287`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.5457373585917956, 2.4057134851798287`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.9143305784008628, 2.4431106893272503`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {0.9143305784008628, 2.4431106893272503`}]}}}},
   Annotation[#, 
    VertexCoordinateRules -> {{0.5582488835898263, 1.2931217454454353`}, {0., 
     0.8642931756789836}, {0.25861831244744926`, 0.5955488229338917}, {
     1.00420156188702, 0.02077377034899297}, {1.2096801965549946`, 
     0.6814332377979534}, {1.3162035821147877`, 0.3187497414663586}, {
     2.276446274374152, 0.7135585047582128}, {1.9894478153023094`, 0.}, {
     2.3491724818958377`, 0.03017949283150867}, {2.3760418755085926`, 
     1.1319257840489372`}, {2.9028777484498867`, 1.6029027289018873`}, {
     2.6381508330238224`, 1.8534543070243594`}, {1.858618963973929, 
     2.4447778624137544`}, {1.8561762614552637`, 2.0199246976037513`}, {
     1.551504577265786, 1.8144692363585486`}, {0.6614251611426085, 
     1.7285055644392184`}, {0.5457373585917956, 2.4057134851798287`}, {
     0.9143305784008628, 2.4431106893272503`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.5732771709718857`*^9, 3.573277211507882*^9, 
  3.573294246232545*^9, 3.573294412181963*^9, 3.573294592125296*^9, 
  3.573294717820395*^9, 3.573295592394511*^9, 3.573454615203703*^9, 
  3.57623641383946*^9, 3.576296947502955*^9}]
}, Open  ]],

Cell[TextData[{
 "Given a sequence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalM]", "1"], ",", "...", ",", 
    SubscriptBox["\[ScriptCapitalM]", "k"]}], TraditionalForm]]],
 " of MDPs, ",
 StyleBox["JoinMDP[", "Program"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalM]", "1"], ",", "...", ",", 
    SubscriptBox["\[ScriptCapitalM]", "k"]}], TraditionalForm]]],
 StyleBox["]", "Program"],
 " yields an MDP representing their disjoint union, where the indices \
representing the set of states are obtained shifting the indices of the \
states of its arguments according to their relative order in the sequence \
(e.g. if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalM]", "1"], TraditionalForm]]],
 " has n states, the index corresponding to the i-th state of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalM]", "2"], TraditionalForm]]],
 " in ",
 StyleBox["JoinMDP[", "Program"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalM]", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalM]", "2"], TraditionalForm]]],
 StyleBox["]", "Program"],
 " is n + i)."
}], "Text",
 CellChangeTimes->{{3.573222435139989*^9, 3.57322256000191*^9}, {
  3.5732226186987267`*^9, 3.573222658366485*^9}, {3.573222724521554*^9, 
  3.5732227293501883`*^9}, {3.5732227593605957`*^9, 3.5732227816191*^9}, {
  3.5734612163879843`*^9, 3.573461216676215*^9}, {3.573461273440157*^9, 
  3.5734612826235437`*^9}, {3.5734613177891283`*^9, 3.573461319828526*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"JoinMDP", "[", 
   RowBox[{"mdp", ",", "mdp"}], "]"}], "//", "PlotMDP"}]], "Input",
 CellChangeTimes->{{3.573274930554284*^9, 3.5732749674908133`*^9}, {
  3.573277254771947*^9, 3.57327725509877*^9}, {3.5732834259430532`*^9, 
  3.5732834319850063`*^9}, {3.573287950197797*^9, 3.573287952970039*^9}, {
  3.5734549185336018`*^9, 3.573454921178316*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.8931899906351171, 
       0.07073281423855815}, {-0.9312034089474646, -0.007536545724638605}, \
{-0.9404140138303647, -0.025004416904376908`}, {-0.9507605672294475, \
-0.04182436335556289}, {-0.9621976941182492, -0.05792262085102762}, \
{-0.974675236737443, -0.07322859014562103}, {-0.9881384745627431, \
-0.08767514659067902}, {-1.0025283642829084`, -0.10119893451057468`}, \
{-1.01778179873542, -0.11374064505036012`}, {-1.2410813521713502`, \
-0.28527207295694074`}, {-1.2571314371001936`, -0.2967767041825713}, \
{-1.2739077845220175`, -0.3071938022930384}, {-1.291336821414109, \
-0.31647768288656997`}, {-1.3093421123704234`, -0.32458763131053053`}, \
{-1.3278446948106577`, -0.33148808121638196`}, {-1.3467634252722993`, \
-0.3371487705366499}, {-1.3660153352669777`, -0.34154487419985347`}, \
{-1.4514388742249433`, -0.35809575552789363`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.8931899906351171, 
       0.07073281423855815}, {-0.8877554490839606, -0.022952121913799278`}, \
{-0.8872267677938275, -0.04424314599891552}, {-0.8881084337826874, \
-0.06552247577181072}, {-0.8903965804858949, -0.08669679028643287}, \
{-0.8940811731881964, -0.10767322914334285`}, {-0.899146053031185, \
-0.12835979973093958`}, {-0.9055690078783123, -0.14866578066098338`}, \
{-0.9133218697266761, -0.16850211962914285`}, {-1.0331740981836268`, \
-0.4475312886337602}, {-1.04222286669534, -0.4668109929603562}, \
{-1.0525278583067217`, -0.48544951109857976`}, {-1.0640438802613983`, \
-0.5033651034370692}, {-1.0767204288040804`, -0.5204792007706875}, \
{-1.0905019106658398`, -0.5367167488674149}, {-1.1053278868695533`, \
-0.5520065376202543}, {-1.1211333377863024`, -0.566281513340646}, \
{-1.192820561777494, -0.6268401082729855}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[
       BezierCurveBox[{{-1.4514388742249433`, -0.35809575552789363`}, \
{-1.413425455912596, -0.279826395564697}, {-1.404214851029696, \
-0.26235852438495866`}, {-1.3938682976306132`, -0.24553857793377268`}, \
{-1.3824311707418113`, -0.22944032043830795`}, {-1.3699536281226175`, \
-0.2141343511437145}, {-1.3564903902973175`, -0.19968779469865655`}, \
{-1.3421005005771522`, -0.18616400677876088`}, {-1.3268470661246405`, \
-0.17362229623897543`}, {-1.1035475126887104`, -0.002090868332394802}, \
{-1.087497427759867, 0.009413762893235728}, {-1.0707210803380431`, 
       0.019830861003702877`}, {-1.0532920434459516`, 
       0.029114741597234456`}, {-1.0352867524896372`, 
       0.037224690021194995`}, {-1.016784170049403, 
       0.04412513992704642}, {-0.9978654395877615, 
       0.04978582924731431}, {-0.9786135295930829, 
       0.054181932910517955`}, {-0.8931899906351171, 0.07073281423855815}}], 
       0.1], InsetBox["0.1`", {-1.2043093434027201`, -0.10203050662240706`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-1.4514388742249433`, -0.35809575552789363`}, \
{-0.4472373123379234, -1.2016151608578842`}}], 0.1], 
      InsetBox["0.8`", {-0.9493380932814334, -0.7798554581928889},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-1.4514388742249433`, -0.35809575552789363`}, \
{-0.7900137130823348, 0.5061166332323412}}], 0.1], 
      InsetBox["0.1`", {-1.120726293653639, 0.0740104388522238},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-1.192820561777494, -0.6268401082729855}, \
{-1.1982551033286506`, -0.5331551721206281}, {-1.1987837846187837`, \
-0.511864148035512}, {-1.197902118629924, -0.4905848182626168}, \
{-1.1956139719267165`, -0.46941050374799465`}, {-1.191929379224415, \
-0.4484340648910846}, {-1.1868644993814261`, -0.4277474943034879}, \
{-1.180441544534299, -0.40744151337344414`}, {-1.1726886826859353`, \
-0.3876051744052847}, {-1.0528364542289845`, -0.10857600540066728`}, \
{-1.0437876857172714`, -0.08929630107407124}, {-1.0334826941058897`, \
-0.07065778293584773}, {-1.021966672151213, -0.05274219059735824}, \
{-1.009290123608531, -0.03562809326373996}, {-0.9955086417467717, \
-0.019390545167012593`}, {-0.9806826655430579, -0.004100756414173207}, \
{-0.9648772146263089, 0.010174219306218549`}, {-0.8931899906351171, 
       0.07073281423855815}}], 0.1], 
      InsetBox["0.1`", {-1.0950512104705996`, -0.25569820215117406`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-1.192820561777494, -0.6268401082729855}, \
{-0.4472373123379234, -1.2016151608578842`}}], 0.1], 
      InsetBox["0.2`", {-0.8200289370577087, -0.9142276345654349},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-1.192820561777494, -0.6268401082729855}, \
{-0.7900137130823348, 0.5061166332323412}}], 0.1], 
      InsetBox["0.7`", {-0.9914171374299144, -0.060361737520322145`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.4472373123379234, -1.2016151608578842`}, \
{-0.46104051036698834`, -1.1172158669699108`}, {-0.46353719988287523`, \
-1.0979681805929296`}, {-0.46475446904571394`, -1.078597451510353}, \
{-0.46468697949611565`, -1.059188630459963}, {-0.4633350272109126, \
-1.0398268352326625`}, {-0.46070454120514526`, -1.0205969773866244`}, \
{-0.4568070575302425, -1.0015833898658737`}, {-0.451659668682427, \
-0.9828694571563986}, {-0.3694682148152373, -0.7186056701768145}, \
{-0.36309349477602554`, -0.7002734626221568}, {-0.35551940001355953`, \
-0.6824033765022032}, {-0.3467791468789302, -0.6650737814536172}, \
{-0.3369110659351753, -0.6483606767781573}, {-0.3259584338577923, \
-0.6323373581461492}, {-0.31396928364397303`, -0.6170740961567889}, \
{-0.30099619396288846`, -0.6026378281649597}, {-0.24175867766994874`, \
-0.5409556934089238}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.4472373123379234, -1.2016151608578842`}, \
{-0.4292149239163697, -1.1514247002217632`}, {-0.424749810174852, \
-1.1401756285680673`}, {-0.4195499455828997, -1.1292467557066952`}, \
{-0.41363813425550305`, -1.1186860104382996`}, {-0.4070403025649607, \
-1.1085397071322698`}, {-0.39978538544023057`, -1.098852342614096}, \
{-0.3919051994721938, -1.0896664010236092`}, {-0.38343430338132956`, \
-1.0810221674998979`}, {-0.2586334952902225, -0.9618317790529516}, \
{-0.24960903836861578`, -0.95376716306304}, {-0.24007059756095975`, \
-0.9463175321491275}, {-0.23006000389903652`, -0.9395155568234932}, \
{-0.21962115905085178`, -0.9333910672912789}, {-0.20879984278895103`, \
-0.9279709226295011}, {-0.19764351222226884`, -0.923278892996007}, \
{-0.18620109367198467`, -0.9193355553849483}, {-0.1352352921101556, \
-0.9036391897405186}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.24175867766994874`, -0.5409556934089238}, \
{-0.8931899906351171, 0.07073281423855815}}], 0.1], 
      InsetBox["0.1`", {-0.5674743341525329, -0.23511143958518282`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.24175867766994874`, -0.5409556934089238}, \
{-0.22795547964088397`, -0.6253549872968973}, {-0.22545879012499703`, \
-0.6446026736738788}, {-0.22424152096215838`, -0.6639734027564553}, \
{-0.22430901051175667`, -0.6833822238068455}, {-0.22566096279695963`, \
-0.7027440190341459}, {-0.228291448802727, -0.7219738768801841}, \
{-0.23218893247762984`, -0.7409874644009347}, {-0.2373363213254452, \
-0.7597013971104096}, {-0.31952777519263503`, -1.0239651840899937`}, \
{-0.3259024952318468, -1.0422973916446514`}, {-0.33347658999431273`, \
-1.060167477764605}, {-0.3422168431289421, -1.0774970728131912`}, \
{-0.3520849240726971, -1.0942101774886508`}, {-0.36303755615008004`, \
-1.1102334961206588`}, {-0.37502670636389923`, -1.1254967581100193`}, \
{-0.3879997960449838, -1.1399330261018488`}, {-0.4472373123379234, \
-1.2016151608578842`}}], 0.1], 
      InsetBox["0.1`", {-0.295206174601657, -0.8866161935200099},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.24175867766994874`, -0.5409556934089238}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.8`", {0.29162436123962987`, -0.5248930599287941},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.1352352921101556, -0.9036391897405186}, \
{-0.8931899906351171, 0.07073281423855815}}], 0.1], 
      InsetBox["0.7`", {-0.5142126413726363, -0.4164531877509802},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.1352352921101556, -0.9036391897405186}, \
{-0.1532576805317094, -0.9538296503766398}, {-0.15772279427322702`, \
-0.9650787220303358}, {-0.16292265886517937`, -0.976007594891708}, \
{-0.16883447019257602`, -0.9865683401601036}, {-0.1754323018831184, \
-0.9967146434661334}, {-0.18268721900784854`, -1.0064020079843072`}, \
{-0.19056740497588526`, -1.015587949574794}, {-0.1990383010667495, \
-1.0242321830985053`}, {-0.3238391091578565, -1.1434225715454516`}, \
{-0.3328635660794633, -1.1514871875353632`}, {-0.3424020068871193, \
-1.1589368184492757`}, {-0.35241260054904255`, -1.16573879377491}, \
{-0.3628514453972273, -1.1718632833071243`}, {-0.37367276165912805`, \
-1.177283427968902}, {-0.38482909222581024`, -1.1819754576023962`}, \
{-0.39627151077609446`, -1.185918795213455}, {-0.4472373123379234, \
-1.2016151608578842`}}], 0.1], 
      InsetBox["0.1`", {-0.2690043071097841, -1.075905654309878},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.1352352921101556, -0.9036391897405186}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.2`", {0.34488605401952643`, -0.7062348080945915},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.8250074001492085, -0.5088304264486644}, {
       0.8327221749163052, -0.6035843991265457}, {
       0.8337600390361755, -0.6251350438296468}, {
       0.8333692558634694, -0.6467071261946512}, {
       0.8315515391859694, -0.6682060414028878}, {
       0.8283148606382056, -0.6895375055117822}, {
       0.8236734147416863, -0.710607968939061}, {
       0.8176475566545267, -0.7313250267264019}, {
       0.8102637129034771, -0.7515978237833126}, {
       0.6954643292747402, -1.0370212256865976`}, {
       0.6867548818610993, -1.056760855237317}, {
       0.6767580262487711, -1.0758807487233402`}, {
       0.6655176038572568, -1.0942970554516434`}, {
       0.6530829097941937, -1.1119290103236543`}, {
       0.6395084766706282, -1.1286992880322808`}, {
       0.6248538354471088, -1.144534342173664}, {
       0.6091832543594131, -1.1593647277864714`}, {
       0.5380089410773661, -1.2223889312068772`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.8250074001492085, -0.5088304264486644}, {
       0.8708240745943512, -0.5803627459545316}, {
       0.8806789463698274, -0.5969324389362188}, {
       0.8894155112837359, -0.6141180624839262}, {
       0.8969954549478081, -0.6318442486859251}, {
       0.9033855353604727, -0.650033258981654}, {
       0.9085577286903486, -0.6686053250858018}, {
       0.912489352175344, -0.6874789988137935}, {
       0.9151631635983847, -0.7065715092745073}, {
       0.9442536466070591, -0.979923114045189}, {
       0.9456579199121918, -0.999150730634432}, {
       0.9457864966294485, -1.018429130237258}, {
       0.9446388128829446, -1.0376737670287504`}, {
       0.9422199018637691, -1.0568002432515091`}, {
       0.9385403717568197, -1.0757246793437814`}, {
       0.9336163592183852, -1.0943640817950349`}, {
       0.9274694586085026, -1.1126367071157344`}, {
       0.8977336076708944, -1.1922094383753685`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{
       0.5380089410773661, -1.2223889312068772`}, {-0.4472373123379234, \
-1.2016151608578842`}}], 0.1], 
      InsetBox["0.1`", {0.04538581436972133, -1.2120020460323806`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5380089410773661, -1.2223889312068772`}, {
       0.5302941663102695, -1.127634958528996}, {
       0.5292563021903993, -1.106084313825895}, {
       0.5296470853631052, -1.0845122314608906`}, {
       0.5314648020406053, -1.063013316252654}, {
       0.5347014805883691, -1.0416818521437594`}, {
       0.5393429264848884, -1.0206113887164807`}, {
       0.545368784572048, -0.9998943309291399}, {
       0.5527526283230977, -0.979621533872229}, {
       0.6675520119518346, -0.6941981319689441}, {
       0.6762614593654753, -0.6744585024182247}, {
       0.6862583149778037, -0.6553386089322017}, {
       0.697498737369318, -0.6369223022038983}, {
       0.709933431432381, -0.6192903473318874}, {
       0.7235078645559465, -0.6025200696232608}, {
       0.7381625057794657, -0.5866850154818778}, {
       0.7538330868671617, -0.5718546298690704}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.1`", {0.6282695516332635, -0.8441967161786083},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5380089410773661, -1.2223889312068772`}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.8`", {0.7313059711805077, -0.6564260391824086},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{
       0.8977336076708944, -1.1922094383753685`}, {-0.4472373123379234, \
-1.2016151608578842`}}], 0.1], 
      InsetBox["0.7`", {0.2252481476664855, -1.1969122996166264`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.8977336076708944, -1.1922094383753685`}, {
       0.8519169332257516, -1.1206771188695017`}, {
       0.8420620614502754, -1.1041074258878143`}, {
       0.833325496536367, -1.086921802340107}, {
       0.8257455528722946, -1.069195616138108}, {
       0.8193554724596301, -1.051006605842379}, {
       0.8141832791297541, -1.0324345397382313`}, {
       0.810251655644759, -1.0135608660102398`}, {
       0.8075778442217182, -0.994468355549526}, {
       0.778487361213044, -0.7211167507788444}, {
       0.7770830879079111, -0.7018891341896012}, {
       0.7769545111906544, -0.6826107345867756}, {
       0.7781021949371585, -0.6633660977952832}, {
       0.780521105956334, -0.6442396215725243}, {
       0.7842006360632834, -0.6253151854802519}, {
       0.7891246486017178, -0.6066757830289986}, {
       0.7952715492116007, -0.5884031577082989}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.1`", {0.810383577691242, -0.8559460366855843},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.8977336076708944, -1.1922094383753685`}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.2`", {0.9111683044772718, -0.6413362927666543},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9246030012836493, -0.09046314715794002}, {
       0.9568135776818536, -0.009270445971918756}, {0.9647299148234807, 
       0.008904121812118498}, {0.973831812595262, 0.026514878889215332`}, {
       0.9840793544340349, 0.04348459291565285}, {0.9954275995306053, 
       0.05973884285542669}, {1.0078267799186065`, 0.07520634535525755}, {
       1.0212225187329578`, 0.08981926735922918}, {1.0355560686807428`, 
       0.10351352359207452`}, {1.2462904178572602`, 0.29190430153325453`}, {
       1.2614989188552113`, 0.3046198355476715}, {1.2775156737039186`, 
       0.3163008831031298}, {1.2942704405897958`, 0.32689621672111435`}, {
       1.311689741132021, 0.33635937034430474`}, {1.3296971826235162`, 
       0.344648843114442}, {1.3482137930527613`, 0.35172828137521095`}, {
       1.3671583674372043`, 0.35756663810196077`}, {1.4514388742249433`, 
       0.38051379769501015`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9246030012836493, -0.09046314715794002}, {
       0.9136959391300881, 0.0037961112552317156`}, {0.9119302634037145, 
       0.02525853095801102}, {0.9115889915424952, 0.04679075341148045}, {
       0.9126736202013199, 0.06829834860344484}, {0.9151793927185061, 
       0.0896869945250797}, {0.9190953199762393, 0.11086289082207494`}, {
       0.9244042285935778, 0.13173317015805175`}, {0.9310828362406761, 
       0.1522063054862098}, {1.0359264192467679`, 0.44081771467637865`}, {
       1.0439454367500198`, 0.46080392063327535`}, {1.0532696965403432`, 
       0.4802155472944162}, {1.06385830688129, 0.4989674645648329}, {
       1.0756648312006114`, 0.5169774355188966}, {1.088637491738819, 
       0.5341664770520765}, {1.1027193966216313`, 0.5504592062629972}, {
       1.1178487893604787`, 0.5657841710467303}, {1.186711958798879, 
       0.6310653758174822}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.4514388742249433`, 0.38051379769501015`}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.1`", {1.138223137187076, -0.06415831437682712},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.4514388742249433`, 0.38051379769501015`}, {
       1.4192282978267392`, 0.29932109650898886`}, {1.411311960685112, 
       0.2811465287249517}, {1.402210062913331, 0.26353577164785486`}, {
       1.3919625210745579`, 0.24656605762141734`}, {1.3806142759779876`, 
       0.2303118076816435}, {1.3682150955899863`, 0.2148443051818126}, {
       1.354819356775635, 0.200231383177841}, {1.34048580682785, 
       0.18653712694499563`}, {
       1.1297514576513326`, -0.0018536509961843417`}, {
       1.1145429566533815`, -0.014569185010601365`}, {
       1.0985262018046742`, -0.026250232566059656`}, {
       1.0817714349187972`, -0.03684556618404419}, {
       1.064352134376572, -0.04630871980723458}, {
       1.0463446928850768`, -0.05459819257737189}, {
       1.0278280824558315`, -0.06167763083814082}, {
       1.0088835080713887`, -0.06751598756489055}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.1`", {1.223160540110936, 0.10571808680455824`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.4514388742249433`, 0.38051379769501015`}, {
       0.4071800897489857, 1.2223889312068772`}}], 0.1], 
      InsetBox["0.8`", {0.9293094819869645, 0.8014513644509437},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.186711958798879, 0.6310653758174822}, {
       0.8250074001492085, -0.5088304264486644}}], 0.1], 
      InsetBox["0.7`", {1.0058596794740438`, 0.06111747468440892},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.186711958798879, 0.6310653758174822}, {
       1.1976190209524404`, 0.5368061174043106}, {1.1993846966788142`, 
       0.5153436977015313}, {1.1997259685400334`, 0.4938114752480618}, {
       1.1986413398812086`, 0.47230388005609747`}, {1.1961355673640224`, 
       0.45091523413446255`}, {1.1922196401062892`, 0.4297393378374673}, {
       1.1869107314889507`, 0.4088690585014905}, {1.1802321238418523`, 
       0.38839592317333244`}, {1.0753885408357604`, 0.09978451398316367}, {
       1.0673695233325087`, 0.07979830802626699}, {1.0580452635421853`, 
       0.06038668136512618}, {1.0474566532012386`, 0.041634764094709495`}, {
       1.035650128881917, 0.023624793140645667`}, {1.0226774683437094`, 
       0.0064357516074657894`}, {
       1.0085955634608972`, -0.009856977603454803}, {
       0.9934661707220498, -0.025181942387188017`}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.1`", {1.1094907422920226`, 0.2507451580523906},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.186711958798879, 0.6310653758174822}, {
       0.4071800897489857, 1.2223889312068772`}}], 0.1], 
      InsetBox["0.2`", {0.7969460242739324, 0.9267271535121797},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.4071800897489857, 1.2223889312068772`}, {
       0.430395336542053, 1.1752832912494646`}, {0.43530717470554026`, 
       1.164424048786084}, {0.4394895022154275, 1.15326351843924}, {
       0.4429239773868924, 1.141850644948336}, {0.445595538257194, 
       1.1302354797089151`}, {0.4474924686402253, 1.118468961271216}, {
       0.44860644950809253`, 1.1066026919480962`}, {0.4489325954743864, 
       1.0946887115120099`}, {0.44795551446692033`, 0.9247474455880085}, {
       0.4474923952116801, 0.9128380030494927}, {0.44624204175409177`, 
       0.9009853275180408}, {0.4442099375454108, 0.8892413991502481}, {
       0.4414049944211723, 0.8776577211897483}, {0.4378395135181494, 
       0.8662850940986598}, {0.4335291313274604, 0.8551733927710964}, {
       0.4284927511204102, 0.8443713478057754}, {0.4047373872303204, 
       0.7975357663968741}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.4071800897489857, 1.2223889312068772`}, {
       0.40806896214150157`, 1.1357268576225306`}, {0.40761934191645893`, 
       1.1160629611455555`}, {0.40586921421161243`, 1.096471941875985}, {
       0.4028262542486384, 1.0770397166388257`}, {0.39850380699213717`, 
       1.0578515058645317`}, {0.3929208286250123, 1.0389914598530245`}, {
       0.38610180341573314`, 1.0205422897307894`}, {0.3780766363420633, 
       1.002584904719501}, {0.2552308816588062, 0.750461454297419}, {
       0.2460347672588976, 0.7330746068848559}, {0.23570803528490708`, 
       0.7163345474542171}, {0.22429597383602382`, 0.7003146898864712}, {
       0.21184863074656324`, 0.685085289602244}, {0.19842059410014165`, 
       0.6707131354552027}, {0.18407075283249333`, 0.657261256828139}, {
       0.16886203847281048`, 0.6447886472162923}, {0.10006570304084272`, 
       0.5920803051516714}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.4047373872303204, 0.7975357663968741}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.1`", {0.6646701942569848, 0.353536309619467},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.4047373872303204, 0.7975357663968741}, {
       0.3815221404372531, 0.8446414063542869}, {0.3766103022737658, 
       0.8555006488176676}, {0.3724279747638787, 0.8666611791645115}, {
       0.3689934995924137, 0.8780740526554153}, {0.3663219387221121, 
       0.8896892178948365}, {0.36442500833908087`, 0.9014557363325356}, {
       0.36331102747121363`, 0.9133220056556551}, {0.3629848815049197, 
       0.9252359860917417}, {0.3639619625123858, 1.095177252015743}, {
       0.36442508176762595`, 1.1070866945542588`}, {0.3656754352252144, 
       1.1189393700857106`}, {0.36770753943389534`, 1.1306832984535033`}, {
       0.3705124825581338, 1.1422669764140032`}, {0.37407796346115674`, 
       1.1536396035050918`}, {0.3783883456518457, 1.164751304832655}, {
       0.3834247258588959, 1.175553349797976}, {0.4071800897489857, 
       1.2223889312068772`}}], 0.1], 
      InsetBox["0.1`", {0.3742604325862832, 1.01014459890163},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.4047373872303204, 
       0.7975357663968741}, {-0.7900137130823348, 0.5061166332323412}}], 0.1],
       InsetBox["0.8`", {-0.19263816292600722`, 0.6518261998146077},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.10006570304084272`, 0.5920803051516714}, {
       0.9246030012836493, -0.09046314715794002}}], 0.1], 
      InsetBox["0.7`", {0.512334352162246, 0.2508085789968657},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.10006570304084272`, 0.5920803051516714}, {
       0.09917683064832686, 0.6787423787360182}, {0.0996264508733695, 
       0.6984062752129931}, {0.10137657857821597`, 0.7179972944825638}, {
       0.10441953854119007`, 0.7374295197197231}, {0.10874198579769123`, 
       0.7566177304940169}, {0.11432496416481613`, 0.7754777765055242}, {
       0.12114398937409532`, 0.7939269466277593}, {0.1291691564477651, 
       0.8118843316390476}, {0.25201491113102226`, 1.0640077820611298`}, {
       0.26121102553093084`, 1.0813946294736927`}, {0.27153775750492143`, 
       1.0981346889043315`}, {0.2829498189538046, 1.1141545464720777`}, {
       0.2953971620432652, 1.1293839467563047`}, {0.3088251986896868, 
       1.143756100903346}, {0.3231750399573352, 1.1572079795304098`}, {
       0.33838375431701806`, 1.1696805891422566`}, {0.4071800897489857, 
       1.2223889312068772`}}], 0.1], 
      InsetBox["0.1`", {0.20659555307462682`, 0.930148430723319},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.10006570304084272`, 
       0.5920803051516714}, {-0.7900137130823348, 0.5061166332323412}}], 0.1],
       InsetBox["0.2`", {-0.34497400502074604`, 0.5490984691920063},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.7900137130823348, 
       0.5061166332323412}, {-0.840238975126165, 
       0.5745918351117142}, {-0.851116802792774, 
       0.590501223363086}, {-0.8609177840586425, 
       0.6070956964039337}, {-0.8695989365153145, 
       0.6243024788254483}, {-0.8771221887870125, 
       0.6420461099232174}, {-0.8834545474934525, 
       0.6602487746317238}, {-0.8885682419430043, 
       0.6788306447839435}, {-0.8924408459216397, 
       0.6977102291994433}, {-0.9387159669419649, 
       0.9685933974956872}, {-0.9413304970638905, 
       0.9876878993619018}, {-0.9426754872525394, 
       1.006913579341288}, {-0.9427450390252916, 
       1.0261861228119415`}, {-0.9415388473613919, 
       1.0454210096311372`}, {-0.9390622020396256, 
       1.0645338848001824`}, {-0.9353259644398825, 
       1.0834409284050295`}, {-0.930346519910348, 
       1.102059223210264}, {-0.9057015156331477, 1.1833245539729516`}}], 
       0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.7900137130823348, 
       0.5061166332323412}, {-0.801555577587796, 
       0.5991017003856502}, {-0.8034748181992128, 
       0.6202798706533093}, {-0.8039881318184305, 
       0.6415386309543895}, {-0.8030932672978299, 
       0.6627847505506883}, {-0.8007941490844933, 
       0.6839250541400782}, {-0.7971008600094615, 
       0.7048668304787442}, {-0.7920295970692657, 
       0.7255182389682845}, {-0.7856026003936617, 
       0.7457887124245764}, {-0.68444043349036, 
       1.031630762379789}, {-0.6766858888077724, 
       1.0514314042172703`}, {-0.6676378038361936, 
       1.0706753783067755`}, {-0.6573358591416243, 
       1.0892782897971982`}, {-0.6458252341181212, 
       1.1071585552308758`}, {-0.6331564088526189, 
       1.1242377603295517`}, {-0.6193849427434521, 
       1.1404410038818324`}, {-0.604571230843451, 
       1.1556972262240188`}, {-0.5371082958240805, 1.220721758120373}}], 
       0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.9057015156331477, 
       1.1833245539729516`}, {-0.8931899906351171, 0.07073281423855815}}], 
       0.1], InsetBox["0.8`", {-0.8994457531341324, 0.6270286841057549},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.9057015156331477, 1.1833245539729516`}, {
       0.4071800897489857, 1.2223889312068772`}}], 0.1], 
      InsetBox["0.1`", {-0.24926071294208102`, 1.2028567425899144`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.9057015156331477, 
       1.1833245539729516`}, {-0.8554762535893177, 
       1.1148493520935787`}, {-0.8445984259227086, 
       1.0989399638422073`}, {-0.8347974446568402, 
       1.0823454908013594`}, {-0.8261162922001681, 
       1.0651387083798447`}, {-0.8185930399284701, 
       1.0473950772820755`}, {-0.8122606812220301, 
       1.0291924125735692`}, {-0.8071469867724785, 
       1.0106105424213496`}, {-0.8032743827938429, 
       0.9917309580058498}, {-0.7569992617735177, 
       0.7208477897096058}, {-0.7543847316515921, 
       0.7017532878433912}, {-0.7530397414629431, 
       0.6825276078640051}, {-0.7529701896901911, 
       0.6632550643933515}, {-0.7541763813540907, 
       0.6440201775741557}, {-0.7566530266758569, 
       0.6249073024051106}, {-0.7603892642756, 
       0.6060002588002634}, {-0.7653687088051346, 
       0.5873819639950291}, {-0.7900137130823348, 0.5061166332323412}}], 0.1],
       InsetBox["0.1`", {-0.7973311134161258, 0.8533520636216689},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.5371082958240805, 
       1.220721758120373}, {-0.8931899906351171, 0.07073281423855815}}], 0.1],
       InsetBox["0.2`", {-0.7151491432295988, 0.6457272861794656},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.5371082958240805, 1.220721758120373}, {
       0.4071800897489857, 1.2223889312068772`}}], 0.1], 
      InsetBox["0.7`", {-0.0649641030375474, 1.2215553446636251`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{-0.5371082958240805, 
       1.220721758120373}, {-0.5255664313186194, 
       1.127736690967064}, {-0.5236471907072027, 
       1.106558520699405}, {-0.5231338770879848, 
       1.085299760398325}, {-0.5240287416085856, 
       1.064053640802026}, {-0.5263278598219221, 
       1.0429133372126365`}, {-0.530021148896954, 
       1.0219715608739703`}, {-0.5350924118371496, 
       1.00132015238443}, {-0.5415194085127537, 
       0.9810496789281379}, {-0.6426815754160553, 
       0.6952076289729254}, {-0.650436120098643, 
       0.6754069871354442}, {-0.6594842050702219, 
       0.6561630130459388}, {-0.6697861497647912, 
       0.6375601015555163}, {-0.6812967747882941, 
       0.6196798361218386}, {-0.6939656000537965, 
       0.6026006310231629}, {-0.7077370661629634, 
       0.586397387470882}, {-0.7225507780629645, 
       0.5711411651286956}, {-0.7900137130823348, 0.5061166332323412}}], 0.1],
       InsetBox["0.1`", {-0.6102442971175176, 0.8445499157818396},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.1517353475677887`, -2.974192523964348}, {
       2.1137219292554414`, -3.052461883927545}, {
       2.1045113243725413`, -3.0699297551072835`}, {
       2.0941647709734585`, -3.0867497015584697`}, {
       2.082727644084657, -3.1028479590539346`}, {
       2.070250101465463, -3.118153928348528}, {
       2.056786863640163, -3.1326004847935858`}, {
       2.0423969739199976`, -3.1461242727134815`}, {
       2.027143539467486, -3.158665983253267}, {
       1.8038439860315558`, -3.330197411159847}, {
       1.7877939011027124`, -3.341702042385478}, {
       1.7710175536808888`, -3.3521191404959447`}, {
       1.7535885167887972`, -3.3614030210894765`}, {
       1.7355832258324828`, -3.369512969513437}, {
       1.7170806433922483`, -3.3764134194192885`}, {
       1.698161912930607, -3.3820741087395563`}, {
       1.6789100029359283`, -3.38647021240276}, {
       1.5934864639779625`, -3.4030210937308}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.1517353475677887`, -2.974192523964348}, {
       2.1571698891189457`, -3.067877460116706}, {
       2.1576985704090785`, -3.089168484201822}, {
       2.156816904420219, -3.110447813974717}, {
       2.1545287577170114`, -3.1316221284893397`}, {
       2.15084416501471, -3.1525985673462493`}, {
       2.145779285171721, -3.173285137933846}, {
       2.1393563303245937`, -3.19359111886389}, {
       2.1316034684762304`, -3.2134274578320494`}, {
       2.0117512400192794`, -3.4924566268366664`}, {
       2.0027024715075665`, -3.511736331163262}, {
       1.9923974798961845`, -3.5303748493014857`}, {
       1.980881457941508, -3.548290441639975}, {
       1.9682049093988259`, -3.5654045389735938`}, {
       1.9544234275370664`, -3.5816420870703207`}, {
       1.939597451333353, -3.5969318758231603`}, {
       1.9237920004166038`, -3.6112068515435523`}, {
       1.8521047764254117`, -3.6717654464758915`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.5934864639779625`, -3.4030210937308}, {
       1.63149988229031, -3.3247517337676036`}, {
       1.6407104871732099`, -3.307283862587865}, {
       1.6510570405722929`, -3.290463916136679}, {
       1.6624941674610945`, -3.274365658641214}, {
       1.6749717100802883`, -3.259059689346621}, {
       1.6884349479055882`, -3.244613132901563}, {
       1.7028248376257538`, -3.231089344981667}, {
       1.7180782720782655`, -3.2185476344418817`}, {
       1.941377825514196, -3.0470162065353015`}, {
       1.9574279104430394`, -3.0355115753096706`}, {
       1.9742042578648633`, -3.025094477199204}, {
       1.9916332947569548`, -3.015810596605672}, {
       2.009638585713269, -3.0077006481817117`}, {
       2.0281411681535033`, -3.00080019827586}, {
       2.047059898615145, -2.9951395089555923`}, {
       2.0663118086098233`, -2.9907434052923887`}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.1`", {1.840615994800186, -3.146955844825314},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.5934864639779625`, -3.4030210937308}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.8`", {2.0955872449214725`, -3.824780796395795},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.5934864639779625`, -3.4030210937308}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.1`", {1.9241990445492667`, -2.9709148993506824`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8521047764254117`, -3.6717654464758915`}, {
       1.8466702348742556`, -3.5780805103235345`}, {
       1.8461415535841224`, -3.556789486238418}, {
       1.8470232195729823`, -3.535510156465523}, {
       1.84931136627619, -3.5143358419509005`}, {
       1.8529959589784915`, -3.493359403093991}, {
       1.85806083882148, -3.4726728325063942`}, {
       1.864483793668607, -3.4523668515763504`}, {
       1.872236655516971, -3.432530512608191}, {
       1.9920888839739215`, -3.153501343603574}, {
       2.0011376524856344`, -3.134221639276978}, {
       2.0114426440970163`, -3.1155831211387546`}, {
       2.022958666051693, -3.0976675288002653`}, {
       2.0356352145943752`, -3.0805534314666465`}, {
       2.0494166964561344`, -3.0643158833699196`}, {
       2.064242672659848, -3.04902609461708}, {
       2.080048123576597, -3.034751118896688}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.1`", {1.9498741277323066`, -3.300623540354081},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8521047764254117`, -3.6717654464758915`}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.2`", {2.2248964011451973`, -3.959152972768341},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8521047764254117`, -3.6717654464758915`}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.7`", {2.0535082007729915`, -3.1052870757232283`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.5976880258649824`, -4.2465404990607905`}, {
       2.5838848278359183`, -4.1621412051728175`}, {
       2.581388138320031, -4.1428935187958364`}, {
       2.5801708691571923`, -4.12352278971326}, {
       2.580238358706791, -4.10411396866287}, {
       2.581590310991994, -4.084752173435569}, {
       2.5842207969977613`, -4.065522315589531}, {
       2.5881182806726644`, -4.046508728068781}, {
       2.5932656695204797`, -4.027794795359306}, {
       2.675457123387669, -3.7635310083797213`}, {
       2.6818318434268806`, -3.7451988008250634`}, {
       2.689405938189347, -3.72732871470511}, {
       2.698146191323976, -3.709999119656524}, {
       2.708014272267731, -3.693286014981064}, {
       2.718966904345114, -3.677262696349056}, {
       2.7309560545589333`, -3.6619994343596955`}, {
       2.7439291442400178`, -3.6475631663678665`}, {
       2.8031666605329573`, -3.5858810316118297`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.5976880258649824`, -4.2465404990607905`}, {
       2.615710414286536, -4.19635003842467}, {
       2.620175528028054, -4.185100966770975}, {
       2.625375392620006, -4.174172093909602}, {
       2.6312872039474025`, -4.163611348641206}, {
       2.6378850356379453`, -4.153465045335177}, {
       2.6451399527626753`, -4.143777680817003}, {
       2.653020138730712, -4.134591739226517}, {
       2.661491034821576, -4.125947505702805}, {
       2.7862918429126835`, -4.006757117255859}, {
       2.7953162998342904`, -3.9986925012659467`}, {
       2.8048547406419466`, -3.9912428703520346`}, {
       2.8148653343038696`, -3.9844408950264003`}, {
       2.8253041791520546`, -3.978316405494186}, {
       2.836125495413955, -3.972896260832408}, {
       2.8472818259806374`, -3.9682042311989134`}, {
       2.8587242445309218`, -3.964260893587855}, {
       2.9096900460927504`, -3.9485645279434247`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.8031666605329573`, -3.5858810316118297`}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.1`", {2.4774510040503728`, -3.280036777788089},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.8031666605329573`, -3.5858810316118297`}, {
       2.8169698585620226`, -3.6702803254998035`}, {
       2.8194665480779095`, -3.689528011876785}, {
       2.8206838172407482`, -3.7088987409593615`}, {
       2.8206163276911496`, -3.7283075620097517`}, {
       2.8192643754059468`, -3.747669357237052}, {
       2.8166338894001792`, -3.7668992150830904`}, {
       2.812736405725276, -3.785912802603841}, {
       2.807589016877461, -3.804626735313316}, {
       2.7253975630102714`, -4.0688905222929}, {
       2.71902284297106, -4.087222729847558}, {
       2.7114487482085936`, -4.105092815967511}, {
       2.7027084950739644`, -4.122422411016098}, {
       2.6928404141302096`, -4.1391355156915575`}, {
       2.6818877820528266`, -4.155158834323565}, {
       2.669898631839007, -4.170422096312926}, {
       2.6569255421579228`, -4.1848583643047546`}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.1`", {2.7497191636012492`, -3.9315415317229156`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.8031666605329573`, -3.5858810316118297`}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.8`", {3.3365496994425357`, -3.5698183981316998`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9096900460927504`, -3.9485645279434247`}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.7`", {2.5307126968302693`, -3.4613785259538865`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9096900460927504`, -3.9485645279434247`}, {
       2.891667657671197, -3.9987549885795466`}, {
       2.8872025439296793`, -4.010004060233243}, {
       2.8820026793377274`, -4.020932933094615}, {
       2.8760908680103308`, -4.03149367836301}, {
       2.869493036319788, -4.04163998166904}, {
       2.862238119195058, -4.051327346187214}, {
       2.8543579332270212`, -4.060513287777701}, {
       2.845887037136157, -4.069157521301412}, {
       2.7210862290450497`, -4.188347909748358}, {
       2.712061772123443, -4.196412525738269}, {
       2.7025233313157866`, -4.203862156652182}, {
       2.6925127376538636`, -4.210664131977816}, {
       2.6820738928056786`, -4.21678862151003}, {
       2.671252576543778, -4.222208766171809}, {
       2.660096245977096, -4.226900795805303}, {
       2.6486538274268114`, -4.230844133416362}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.1`", {2.775921031093122, -4.120830992512784},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9096900460927504`, -3.9485645279434247`}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.2`", {3.389811392222432, -3.7511601462974973`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.869932738352114, -3.5537557646515703`}, {
       3.877647513119211, -3.6485097373294524`}, {
       3.8786853772390812`, -3.670060382032553}, {
       3.8782945940663756`, -3.6916324643975575`}, {
       3.876476877388875, -3.7131313796057945`}, {
       3.873240198841111, -3.734462843714689}, {
       3.868598752944592, -3.7555333071419676`}, {
       3.8625728948574327`, -3.776250364929308}, {
       3.855189051106383, -3.796523161986219}, {
       3.740389667477646, -4.081946563889504}, {
       3.7316802200640056`, -4.101686193440224}, {
       3.721683364451677, -4.120806086926247}, {
       3.710442942060163, -4.13922239365455}, {
       3.6980082479971, -4.156854348526561}, {
       3.6844338148735343`, -4.1736246262351875`}, {
       3.6697791736500145`, -4.189459680376571}, {
       3.654108592562319, -4.204290065989379}, {
       3.5829342792802716`, -4.267314269409783}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.869932738352114, -3.5537557646515703`}, {
       3.9157494127972576`, -3.625288084157438}, {
       3.925604284572734, -3.6418577771391254`}, {
       3.934340849486642, -3.659043400686833}, {
       3.941920793150715, -3.676769586888832}, {
       3.948310873563379, -3.69495859718456}, {
       3.9534830668932552`, -3.7135306632887084`}, {
       3.9574146903782506`, -3.7324043370167}, {
       3.960088501801291, -3.751496847477414}, {
       3.989178984809966, -4.024848452248095}, {
       3.9905832581150986`, -4.044076068837338}, {
       3.9907118348323554`, -4.063354468440164}, {
       3.9895641510858515`, -4.082599105231656}, {
       3.987145240066676, -4.101725581454415}, {
       3.9834657099597264`, -4.120650017546688}, {
       3.9785416974212917`, -4.139289419997941}, {
       3.972394796811409, -4.157562045318641}, {
       3.9426589458738004`, -4.237134776578275}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.5829342792802716`, -4.267314269409783}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.1`", {3.0903111525726272`, -4.256927384235286},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.5829342792802716`, -4.267314269409783}, {
       3.575219504513175, -4.172560296731903}, {
       3.574181640393305, -4.151009652028802}, {
       3.5745724235660106`, -4.129437569663797}, {
       3.576390140243511, -4.107938654455561}, {
       3.579626818791275, -4.086607190346666}, {
       3.584268264687794, -4.065536726919388}, {
       3.5902941227749534`, -4.044819669132047}, {
       3.5976779665260032`, -4.0245468720751365`}, {
       3.71247735015474, -3.7391234701718505`}, {
       3.7211867975683806`, -3.7193838406211315`}, {
       3.731183653180709, -3.700263947135108}, {
       3.742424075572224, -3.681847640406805}, {
       3.7548587696352866`, -3.664215685534794}, {
       3.7684332027588514`, -3.6474454078261673`}, {
       3.783087843982371, -3.6316103536847844`}, {
       3.798758425070067, -3.616779968071977}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.1`", {3.673194889836169, -3.889122054381515},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.5829342792802716`, -4.267314269409783}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.8`", {3.7762313093834132`, -3.701351377385315},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.9426589458738004`, -4.237134776578275}, {
       2.5976880258649824`, -4.2465404990607905`}}], 0.1], 
      InsetBox["0.7`", {3.2701734858693916`, -4.241837637819533},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.9426589458738004`, -4.237134776578275}, {
       3.8968422714286586`, -4.165602457072407}, {
       3.8869873996531825`, -4.1490327640907205`}, {
       3.8782508347392737`, -4.131847140543013}, {
       3.8706708910752012`, -4.114120954341015}, {
       3.8642808106625366`, -4.095931944045285}, {
       3.8591086173326605`, -4.077359877941137}, {
       3.855176993847665, -4.058486204213146}, {
       3.852503182424625, -4.039393693752432}, {
       3.8234126994159503`, -3.7660420889817505`}, {
       3.8220084261108176`, -3.7468144723925074`}, {
       3.821879849393561, -3.727536072789682}, {
       3.8230275331400647`, -3.7082914359981896`}, {
       3.82544644415924, -3.6891649597754306`}, {
       3.82912597426619, -3.670240523683158}, {
       3.8340499868046236`, -3.651601121231905}, {
       3.840196887414507, -3.633328495911205}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.1`", {3.855308915894149, -3.9008713748884905`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.9426589458738004`, -4.237134776578275}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.2`", {3.9560936426801776`, -3.68626163096956},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.969528339486555, -3.135388485360846}, {
       4.00173891588476, -3.054195784174825}, {
       4.009655253026388, -3.0360212163907883`}, {
       4.0187571507981685`, -3.018410459313691}, {
       4.029004692636942, -3.0014407452872534`}, {
       4.040352937733512, -2.98518649534748}, {
       4.052752118121513, -2.969718992847649}, {
       4.0661478569358644`, -2.9551060708436774`}, {
       4.080481406883649, -2.9414118146108317`}, {
       4.291215756060167, -2.7530210366696513`}, {
       4.306424257058118, -2.7403055026552345`}, {
       4.322441011906825, -2.728624455099776}, {
       4.3391957787927025`, -2.7180291214817918`}, {
       4.356615079334928, -2.708565967858601}, {
       4.374622520826423, -2.7002764950884637`}, {
       4.393139131255668, -2.693197056827695}, {
       4.412083705640111, -2.6873587001009454`}, {
       4.496364212427849, -2.6644115405078956`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.969528339486555, -3.135388485360846}, {
       3.9586212773329934`, -3.0411292269476746`}, {
       3.95685560160662, -3.0196668072448953`}, {
       3.9565143297454006`, -2.998134584791426}, {
       3.9575989584042253`, -2.9766269895994615`}, {
       3.960104730921412, -2.9552383436778267`}, {
       3.964020658179145, -2.9340624473808314`}, {
       3.969329566796483, -2.913192168044855}, {
       3.976008174443582, -2.8927190327166965`}, {
       4.080851757449674, -2.6041076235265277`}, {
       4.088870774952927, -2.584121417569631}, {
       4.098195034743249, -2.5647097909084904`}, {
       4.108783645084197, -2.5459578736380735`}, {
       4.120590169403518, -2.52794790268401}, {
       4.1335628299417255`, -2.51075886115083}, {
       4.147644734824537, -2.4944661319399093`}, {
       4.162774127563385, -2.4791411671561763`}, {
       4.231637297001785, -2.4138599623854238`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.496364212427849, -2.6644115405078956`}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.1`", {4.183148475389982, -3.109083652579733},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.496364212427849, -2.6644115405078956`}, {
       4.464153636029646, -2.7456042416939175`}, {
       4.456237298888018, -2.7637788094779543`}, {
       4.447135401116237, -2.7813895665550517`}, {
       4.436887859277464, -2.798359280581489}, {
       4.425539614180894, -2.814613530521263}, {
       4.413140433792893, -2.8300810330210937`}, {
       4.3997446949785415`, -2.844693955025065}, {
       4.385411145030757, -2.858388211257911}, {
       4.174676795854239, -3.0467789891990913`}, {
       4.159468294856288, -3.059494523213508}, {
       4.143451540007581, -3.0711755707689665`}, {
       4.1266967731217035`, -3.081770904386951}, {
       4.109277472579478, -3.091234058010141}, {
       4.0912700310879835`, -3.099523530780279}, {
       4.072753420658738, -3.1066029690410475`}, {
       4.053808846274295, -3.112441325767797}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.1`", {4.268085878313843, -2.939207251398349},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.496364212427849, -2.6644115405078956`}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.8`", {3.9742348201898703`, -2.2434739737519624`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.231637297001785, -2.4138599623854238`}, {
       3.869932738352114, -3.5537557646515703`}}], 0.1], 
      InsetBox["0.7`", {4.050785017676949, -2.9838078635184972`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.231637297001785, -2.4138599623854238`}, {
       4.242544359155347, -2.508119220798595}, {
       4.244310034881721, -2.529581640501375}, {
       4.24465130674294, -2.5511138629548444`}, {
       4.2435666780841155`, -2.5726214581468088`}, {
       4.241060905566929, -2.5940101040684436`}, {
       4.237144978309196, -2.615186000365439}, {
       4.231836069691857, -2.6360562797014158`}, {
       4.225157462044759, -2.6565294150295737`}, {
       4.120313879038667, -2.9451408242197425`}, {
       4.112294861535415, -2.965127030176639}, {
       4.102970601745092, -2.98453865683778}, {
       4.092381991404145, -3.0032905741081968`}, {
       4.080575467084824, -3.0213005450622603`}, {
       4.067602806546615, -3.0384895865954404`}, {
       4.053520901663804, -3.054782315806361}, {
       4.038391508924956, -3.070107280590094}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.1`", {4.154416080494929, -2.7941801801505157`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{4.231637297001785, -2.4138599623854238`}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.2`", {3.841871362476838, -2.1181981846907263`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.4521054279518912`, -1.8225364069960288`}, {
       3.4753206747449594`, -1.8696420469534414`}, {
       3.4802325129084464`, -1.8805012894168223`}, {
       3.4844148404183337`, -1.891661819763666}, {
       3.487849315589799, -1.90307469325457}, {
       3.4905208764601006`, -1.914689858493991}, {
       3.4924178068431315`, -1.92645637693169}, {
       3.493531787710999, -1.9383226462548098`}, {
       3.493857933677293, -1.9502366266908961`}, {
       3.4928808526698267`, -2.1201778926148975`}, {
       3.492417733414586, -2.132087335153413}, {
       3.491167379956998, -2.143940010684865}, {
       3.489135275748317, -2.1556839390526576`}, {
       3.4863303326240787`, -2.1672676170131577`}, {
       3.4827648517210554`, -2.1786402441042463`}, {
       3.4784544695303667`, -2.1897519454318095`}, {
       3.4734180893233164`, -2.2005539903971307`}, {
       3.4496627254332264`, -2.247389571806032}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.4521054279518912`, -1.8225364069960288`}, {
       3.4529943003444075`, -1.9091984805803754`}, {
       3.452544680119365, -1.9288623770573503`}, {
       3.4507945524145183`, -1.948453396326921}, {
       3.447751592451544, -1.9678856215640805`}, {
       3.4434291451950427`, -1.987073832338374}, {
       3.437846166827918, -2.0059338783498815`}, {
       3.4310271416186384`, -2.0243830484721164`}, {
       3.423001974544969, -2.042340433483405}, {
       3.300156219861712, -2.294463883905488}, {
       3.290960105461803, -2.3118507313180507`}, {
       3.280633373487813, -2.32859079074869}, {
       3.2692213120389297`, -2.344610648316436}, {
       3.256773968949469, -2.3598400486006628`}, {
       3.2433459323030474`, -2.374212202747704}, {
       3.228996091035399, -2.387664081374768}, {
       3.2137873766757163`, -2.4001366909866144`}, {
       3.1449910412437485`, -2.4528450330512346`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.4496627254332264`, -2.247389571806032}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.1`", {3.7095955324598906`, -2.6913890285834388`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.4496627254332264`, -2.247389571806032}, {
       3.426447478640159, -2.200283931848619}, {
       3.421535640476672, -2.1894246893852385`}, {
       3.417353312966785, -2.1782641590383944`}, {
       3.4139188377953196`, -2.166851285547491}, {
       3.411247276925018, -2.1552361203080697`}, {
       3.409350346541987, -2.1434696018703705`}, {
       3.4082363656741195`, -2.131603332547251}, {
       3.4079102197078255`, -2.1196893521111644`}, {
       3.408887300715292, -1.9497480861871634`}, {
       3.4093504199705325`, -1.9378386436486477`}, {
       3.4106007734281203`, -1.9259859681171958`}, {
       3.4126328776368013`, -1.9142420397494029`}, {
       3.41543782076104, -1.9026583617889032`}, {
       3.419003301664063, -1.8912857346978147`}, {
       3.4233136838547518`, -1.8801740333702512`}, {
       3.428350064061802, -1.8693719884049305`}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.1`", {3.4191857707891895`, -2.034780739301276},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.4496627254332264`, -2.247389571806032}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.8`", {2.852287175276899, -2.3930991383882985`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.1449910412437485`, -2.4528450330512346`}, {
       3.969528339486555, -3.135388485360846}}], 0.1], 
      InsetBox["0.7`", {3.557259690365152, -2.79411675920604},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.1449910412437485`, -2.4528450330512346`}, {
       3.1441021688512327`, -2.3661829594668884`}, {
       3.1445517890762753`, -2.346519062989913}, {
       3.146301916781122, -2.3269280437203426`}, {
       3.149344876744096, -2.3074958184831833`}, {
       3.1536673240005975`, -2.2883076077088895`}, {
       3.159250302367722, -2.269447561697382}, {
       3.1660693275770018`, -2.250998391575147}, {
       3.1740944946506713`, -2.233041006563859}, {
       3.2969402493339284`, -1.980917556141776}, {
       3.3061363637338372`, -1.963530708729213}, {
       3.316463095707827, -1.946790649298574}, {
       3.3278751571567105`, -1.930770791730828}, {
       3.340322500246171, -1.915541391446601}, {
       3.353750536892593, -1.9011692372995599`}, {
       3.368100378160241, -1.8877173586724962`}, {
       3.383309092519924, -1.8752447490606492`}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.1`", {3.251520891277533, -2.114776907479587},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{3.1449910412437485`, -2.4528450330512346`}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.2`", {2.6999513331821596`, -2.4958268690109},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.254911625120571, -2.538808704970565}, {
       2.204686363076741, -2.470333503091192}, {
       2.193808535410132, -2.4544241148398207`}, {
       2.1840075541442636`, -2.437829641798973}, {
       2.1753264016875913`, -2.4206228593774584`}, {
       2.1678031494158936`, -2.402879228279689}, {
       2.161470790709453, -2.384676563571183}, {
       2.1563570962599017`, -2.366094693418963}, {
       2.1524844922812663`, -2.3472151090034634`}, {
       2.1062093712609413`, -2.0763319407072194`}, {
       2.103594841139016, -2.0572374388410046`}, {
       2.1022498509503666`, -2.0380117588616184`}, {
       2.1021802991776144`, -2.0187392153909647`}, {
       2.103386490841514, -1.999504328571769}, {
       2.1058631361632805`, -1.9803914534027238`}, {
       2.1095993737630234`, -1.9614844097978767`}, {
       2.114578818292558, -1.9428661149926425`}, {
       2.139223822569758, -1.8616007842299545`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.254911625120571, -2.538808704970565}, {
       2.24336976061511, -2.445823637817256}, {
       2.241450520003693, -2.4246454675495968`}, {
       2.240937206384475, -2.403386707248517}, {
       2.241832070905076, -2.382140587652218}, {
       2.244131189118413, -2.361000284062828}, {
       2.2478244781934444`, -2.3400585077241622`}, {
       2.25289574113364, -2.319407099234622}, {
       2.259322737809244, -2.29913662577833}, {
       2.360484904712546, -2.0132945758231173`}, {
       2.3682394493951335`, -1.9934939339856363`}, {
       2.377287534366712, -1.9742499598961307`}, {
       2.387589479061282, -1.9556470484057085`}, {
       2.3991001040847846`, -1.9377667829720306`}, {
       2.411768929350287, -1.920687577873355}, {
       2.425540395459454, -1.9044843343210738`}, {
       2.4403541073594552`, -1.8892281119788876`}, {
       2.507817042378825, -1.824203580082533}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.139223822569758, -1.8616007842299545`}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.8`", {2.1454795850687733`, -2.4178966540971514`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.139223822569758, -1.8616007842299545`}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.1`", {2.795664625260825, -1.8420685956129916`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.139223822569758, -1.8616007842299545`}, {
       2.1894490846135883`, -1.9300759861093275`}, {
       2.200326912280197, -1.9459853743606994`}, {
       2.210127893546066, -1.9625798474015472`}, {
       2.218809046002738, -1.9797866298230617`}, {
       2.226332298274436, -1.9975302609208307`}, {
       2.232664656980876, -2.015732925629337}, {
       2.2377783514304275`, -2.034314795781557}, {
       2.2416509554090633`, -2.0531943801970565`}, {
       2.2879260764293883`, -2.3240775484933005`}, {
       2.2905406065513136`, -2.3431720503595153`}, {
       2.291885596739963, -2.3623977303389014`}, {
       2.291955148512715, -2.381670273809555}, {
       2.2907489568488155`, -2.4009051606287506`}, {
       2.288272311527049, -2.4200180357977956`}, {
       2.284536073927306, -2.438925079402643}, {
       2.2795566293977716`, -2.457543374207878}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.1`", {2.2475942247867806`, -2.1915732745812377`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.507817042378825, -1.824203580082533}, {
       2.1517353475677887`, -2.974192523964348}}], 0.1], 
      InsetBox["0.2`", {2.3297761949733067`, -2.3991980520234404`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.507817042378825, -1.824203580082533}, {
       3.4521054279518912`, -1.8225364069960288`}}], 0.1], 
      InsetBox["0.7`", {2.979961235165358, -1.8233699935392809`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.507817042378825, -1.824203580082533}, {
       2.5193589068842868`, -1.9171886472358424`}, {
       2.521278147495704, -1.9383668175035011`}, {
       2.5217914611149217`, -1.9596255778045815`}, {
       2.5208965965943206`, -1.9808716974008804`}, {
       2.5185974783809844`, -2.00201200099027}, {
       2.5149041893059523`, -2.022953777328936}, {
       2.509832926365757, -2.0436051858184765`}, {
       2.5034059296901527`, -2.0638756592747685`}, {
       2.402243762786851, -2.349717709229981}, {
       2.394489218104263, -2.369518351067462}, {
       2.3854411331326846`, -2.3887623251569674`}, {
       2.375139188438115, -2.40736523664739}, {
       2.363628563414612, -2.4252455020810677`}, {
       2.3509597381491094`, -2.4423247071797434`}, {
       2.337188272039943, -2.458527950732025}, {
       2.3223745601399415`, -2.4737841730742107`}, {
       2.254911625120571, -2.538808704970565}}], 0.1], 
      InsetBox["0.1`", {2.4346810410853887`, -2.2003754224210668`},
       Background->GrayLevel[1]]}}, {
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.8931899906351171, 0.07073281423855815}, 0.1], 
      {GrayLevel[0], 
       InsetBox["1", {-0.8931899906351171, 0.07073281423855815}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-1.4514388742249433`, -0.35809575552789363`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{
        "-", "1"}], {-1.4514388742249433`, -0.35809575552789363`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-1.192820561777494, -0.6268401082729855}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {-1.192820561777494, -0.6268401082729855}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.4472373123379234, -1.2016151608578842`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["2", {-0.4472373123379234, -1.2016151608578842`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.24175867766994874`, -0.5409556934089238}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {-0.24175867766994874`, -0.5409556934089238}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.1352352921101556, -0.9036391897405186}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {-0.1352352921101556, -0.9036391897405186}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.8250074001492085, -0.5088304264486644}, 0.1], 
      {GrayLevel[0], 
       InsetBox["3", {0.8250074001492085, -0.5088304264486644}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.5380089410773661, -1.2223889312068772`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.5380089410773661, -1.2223889312068772`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.8977336076708944, -1.1922094383753685`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.8977336076708944, -1.1922094383753685`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.9246030012836493, -0.09046314715794002}, 0.1], 
      {GrayLevel[0], 
       InsetBox["4", {0.9246030012836493, -0.09046314715794002}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.4514388742249433`, 0.38051379769501015`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.4514388742249433`, 0.38051379769501015`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.186711958798879, 0.6310653758174822}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.186711958798879, 0.6310653758174822}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.4071800897489857, 1.2223889312068772`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["5", {0.4071800897489857, 1.2223889312068772`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.4047373872303204, 0.7975357663968741}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.4047373872303204, 0.7975357663968741}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.10006570304084272`, 0.5920803051516714}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {0.10006570304084272`, 0.5920803051516714}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.7900137130823348, 0.5061166332323412}, 0.1], 
      {GrayLevel[0], 
       InsetBox["6", {-0.7900137130823348, 0.5061166332323412}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.9057015156331477, 1.1833245539729516`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {-0.9057015156331477, 1.1833245539729516`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{-0.5371082958240805, 1.220721758120373}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {-0.5371082958240805, 1.220721758120373}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.1517353475677887`, -2.974192523964348}, 0.1], 
      {GrayLevel[0], 
       InsetBox["7", {2.1517353475677887`, -2.974192523964348}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.5934864639779625`, -3.4030210937308}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.5934864639779625`, -3.4030210937308}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.8521047764254117`, -3.6717654464758915`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.8521047764254117`, -3.6717654464758915`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.5976880258649824`, -4.2465404990607905`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["8", {2.5976880258649824`, -4.2465404990607905`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.8031666605329573`, -3.5858810316118297`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.8031666605329573`, -3.5858810316118297`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.9096900460927504`, -3.9485645279434247`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.9096900460927504`, -3.9485645279434247`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.869932738352114, -3.5537557646515703`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["9", {3.869932738352114, -3.5537557646515703`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.5829342792802716`, -4.267314269409783}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {3.5829342792802716`, -4.267314269409783}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.9426589458738004`, -4.237134776578275}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {3.9426589458738004`, -4.237134776578275}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.969528339486555, -3.135388485360846}, 0.1], 
      {GrayLevel[0], 
       InsetBox["10", {3.969528339486555, -3.135388485360846}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{4.496364212427849, -2.6644115405078956`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {4.496364212427849, -2.6644115405078956`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{4.231637297001785, -2.4138599623854238`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {4.231637297001785, -2.4138599623854238`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.4521054279518912`, -1.8225364069960288`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["11", {3.4521054279518912`, -1.8225364069960288`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.4496627254332264`, -2.247389571806032}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {3.4496627254332264`, -2.247389571806032}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{3.1449910412437485`, -2.4528450330512346`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {3.1449910412437485`, -2.4528450330512346`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.254911625120571, -2.538808704970565}, 0.1], 
      {GrayLevel[0], 
       InsetBox["12", {2.254911625120571, -2.538808704970565}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.139223822569758, -1.8616007842299545`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.139223822569758, -1.8616007842299545`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.507817042378825, -1.824203580082533}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {2.507817042378825, -1.824203580082533}]}}}},
   Annotation[#, VertexCoordinateRules -> CompressedData["
1:eJwBUQKu/SFib1JlAgAAACQAAAACAAAAVI7cLAOV7L9QneizixuyP+sGD/gX
Ofe/qAm1dQrr1r98Sm0DyxXzv3ZQm/wSD+S/WLWCP4mf3L/CMqTR0Dnzv+jt
Dsfy8c6/s9d4UIJP4b9oZnDaY0/BvxE56ruc6uy/qilT63Vm6j/f0Bm/Vkjg
v4pA3IZeN+E/N2oosueO879G7q7UO7rsPzLgPDRKE/O/un6JCFmW7T/QXYnC
lyi3v+sGD/gXOfc/kLcxi1Za2D83A82txfzyP+bE2AOwMeQ/pHhDFD0P2j83
aiiy547zP4zaZ6Q359k/ahNCummF6T+g/ALq5525P5ptZ2VS8uI/opCi1spH
6b+cOXaCGzLgP8Ofsr6B++y/v+E9uuXu8j/mMJ+8/S/hvzFIyokTiPM/VZub
BcE2AUAAejNzJcsHwOl2lqnrfvk/IGCJH2M5C8BYMzieOKL9PwiT+Y/GXw3A
P2jiqBDIBEAmbNIcdfwQwAzQYaTibAZA1/TwZOKvDMCEuCuTC0cHQC9Nzf+o
lg/AVImnS5/1DkAiM5mAF24MwAzPiXLZqQxAA3rz1LoREcB8ev7FkIoPQIKX
eHXT8hDAmB71EpjBD0DZCeeORhUJwDAhbeZG/BFA+Ids/7ZQBcBDoNxTMu0Q
QLGN3M+VTwPA/i1bc+mdC0CeE33vGyn9vzy6X8XomAtAEDpCYqf6AcDP1iIQ
8SgJQITjeDdtnwPAwhoqGw8KAkCEMDXwek8EwPkWJmEhHQFAFpxn5x3J/b+w
8qphAhAEQKQ12xfwL/2/SccjnA==
     "]]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  ImageSize->{681.4296875, Automatic},
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.5732879783477173`*^9, 3.573454615315419*^9, 
  3.57623641394597*^9, 3.576296947625993*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Computing Bisimilarity Distances\
\>", "Subsection",
 CellChangeTimes->{{3.573275045172209*^9, 3.573275070429124*^9}}],

Cell[TextData[{
 "Given an MDP \[ScriptCapitalM], a discount factor \[Lambda], and a list of \
state pairs Q, ",
 StyleBox["BDistMDP[", "Program"],
 "\[ScriptCapitalM],\[Lambda],Q",
 StyleBox["]", "Program"],
 " computes the distance ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", "\[Lambda]"], "(", 
    RowBox[{"s", ",", "t"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " associated with each pair of states (s,t) in Q. For example, taking MDP ",
 StyleBox["mdp", "Program"],
 " considered so far, a discount factor 0.5 and a single-pair query Q = \
{(1,2)} we have"
}], "Text",
 CellChangeTimes->{{3.573296492282545*^9, 3.573297003050696*^9}, {
  3.573461369592918*^9, 3.573461378704226*^9}, {3.573461462333082*^9, 
  3.57346146719392*^9}, {3.573461514271017*^9, 3.573461518622538*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp", ",", "0.5", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.573294152209256*^9, 3.573294197425992*^9}, {
  3.573294278093342*^9, 3.573294286627157*^9}, {3.573294438414069*^9, 
  3.573294438908588*^9}, {3.573294791470829*^9, 3.573294792158311*^9}, {
  3.573294845248114*^9, 3.573294853697061*^9}, {3.573296471971945*^9, 
  3.573296482363071*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "2.293751388764115`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.573294182052299*^9, 3.5732941987870092`*^9}, 
   3.57329425211889*^9, 3.573294288479952*^9, {3.573294421397935*^9, 
   3.573294439874086*^9}, 3.57329460201659*^9, 3.5732947298731937`*^9, 
   3.573294793772306*^9, {3.573294846812064*^9, 3.573294855193079*^9}, 
   3.573294887501624*^9, 3.573296484148332*^9, 3.573454616145273*^9, 
   3.576236414461657*^9, 3.5762969481691513`*^9}]
}, Open  ]],

Cell["\<\
while for the query Q = {(1,2),(3,4),(6,5)} we have\
\>", "Text",
 CellChangeTimes->{{3.57329701832286*^9, 3.5732970831259413`*^9}, {
  3.57329711446761*^9, 3.573297115731452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp", ",", "0.5", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "5"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.573297091998274*^9, 3.573297099334128*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "2.293751388764115`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", "2.541025094655766`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", "2.2864868084782946`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.573297102002808*^9, 3.573454617010795*^9, 
  3.576236414979525*^9, 3.5762969486710663`*^9}]
}, Open  ]],

Cell[TextData[{
 "If one is interested in computing the distance between all state pairs, it \
can use the alias ",
 StyleBox["All ", "Program"],
 "as follows"
}], "Text",
 CellChangeTimes->{{3.573297124300226*^9, 3.573297171287444*^9}, {
  3.573461539970664*^9, 3.5734615825547123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp", ",", "0.5", ",", "All"}], "]"}]], "Input",
 CellChangeTimes->{{3.573297180640841*^9, 3.573297180936481*^9}, {
  3.573889954558605*^9, 3.573889956307126*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "2.293751388764115`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "2.8403194968264462`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", "2.713269814954547`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", "7.073433987246145`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", "6.145209450475829`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "2.293751388764115`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1.0250222851644575`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "3.194382631903265`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", "6.891516746769152`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", "7.873452710465528`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "2.8403194968264462`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "1.0250222851644575`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", "2.541025094655766`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", "7.2316188086275215`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], "\[Rule]", "7.978748692141727`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", "2.713269814954547`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", "3.194382631903265`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", "2.541025094655766`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}], "\[Rule]", "6.275569304580435`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "6"}], "}"}], "\[Rule]", "7.520039458604741`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", "7.073433987246145`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], "\[Rule]", "6.891516746769152`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", "7.2316188086275215`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}], "\[Rule]", "6.275569304580435`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], "\[Rule]", "2.2864868084782946`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", "6.145209450475829`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", "7.873452710465528`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", "7.978748692141727`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "4"}], "}"}], "\[Rule]", "7.520039458604741`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", "2.2864868084782946`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.573297606464037*^9, 3.5734546178359823`*^9, 
  3.57623641561452*^9, 3.576296949212319*^9}]
}, Open  ]],

Cell[TextData[{
 "The computation can be traced setting the option ",
 StyleBox["Verbose", "Program"],
 " to ",
 StyleBox["True", "Program"],
 ". It will display the couplings encoutered during each iteration of the \
on-the-fly algorithm. This option can be also used to analyze how the \
algorithm explores the state space of the MDP."
}], "Text",
 CellChangeTimes->{{3.5732972155579557`*^9, 3.5732972560316963`*^9}, {
  3.573297355961733*^9, 3.573297496815564*^9}, {3.573461598882535*^9, 
  3.57346160489538*^9}, {3.573461648413136*^9, 3.5734616491962337`*^9}, {
  3.573461684210103*^9, 3.5734617539055853`*^9}}],

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp", ",", "0.5", ",", "All", ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.57329727145581*^9, 3.573297279599216*^9}}],

Cell[TextData[{
 "One can provide some estimates in order to further reduce the exploration \
of the state space. This can be done using the option ",
 StyleBox["Estimates", "Program"]
}], "Text",
 CellChangeTimes->{{3.57329750647598*^9, 3.573297596625525*^9}, 
   3.5734616580594683`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp", ",", "0.5", ",", "All", ",", " ", 
   RowBox[{"Estimates", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", "6.145"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "2.293"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1.025"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "2.866"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.573297635373744*^9, 3.573297740812786*^9}, {
  3.576236530524798*^9, 3.576236532827046*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "2.293`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "2.794959253554873`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", "2.7132414867517087`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", "7.006914015330761`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", "6.145`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "2.293`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1.025`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "2.866`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", "6.8914537390129835`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", "7.7350366600057905`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "2.794959253554873`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "1.025`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", "2.5407068012430263`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", "6.818311693297041`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], "\[Rule]", "7.9627250560050005`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", "2.7132414867517087`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", "2.866`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", "2.5407068012430263`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}], "\[Rule]", "6.27466889736588`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "6"}], "}"}], "\[Rule]", "7.351656682935268`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", "7.006914015330761`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], "\[Rule]", "6.8914537390129835`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", "6.818311693297041`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}], "\[Rule]", "6.27466889736588`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], "\[Rule]", "2.2864120745145846`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", "6.145`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", "7.7350366600057905`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", "7.9627250560050005`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "4"}], "}"}], "\[Rule]", "7.351656682935268`"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", "2.2864120745145846`"}], ",", 
   
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.573297720563374*^9, 3.573297743046153*^9}, 
   3.573297874129098*^9, 3.573454275093913*^9, 3.57345455720807*^9, 
   3.57345462113302*^9, 3.576236419130989*^9, 3.576236537680417*^9, 
   3.576296949853447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exact Computations", "Subsubsection",
 CellChangeTimes->{{3.5762365933141527`*^9, 3.576236601239747*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " allows one to perform exact computations over Rational numbers. Usually \
the Bellman-optimality equation system is computed approximately since it is \
in general a non-linear equation system. Despite this fact, our method is \
able to compute the exact result when the input MDP is rational-valued (i.e. \
both the transition fuction and the reward function are rational-valued)"
}], "Text",
 CellChangeTimes->{{3.57623661460704*^9, 3.5762370149122868`*^9}}],

Cell["\<\
For example, the MDP we considered so far can be rationalized as follows\
\>", "Text",
 CellChangeTimes->{{3.57623702439981*^9, 3.5762370615623827`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"tm1", "=", 
   RowBox[{
    StyleBox["MDPtm",
     FontSlant->"Italic"], "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "1", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{"i", ",", "6"}], "]"}]}]}], ")"}], "\[Rule]", " ", 
        RowBox[{"4", "/", "5"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "1", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "-", "2"}], ",", "6"}], "]"}]}]}], ")"}], "\[Rule]",
         " ", 
        RowBox[{"1", "/", "10"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i_", ",", "_", ",", "i_"}], "}"}], "\[Rule]", 
        RowBox[{"1", "/", "10"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "2", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{
             RowBox[{"i", "-", "2"}], ",", "6"}], "]"}]}]}], ")"}], "\[Rule]",
         " ", 
        RowBox[{"7", "/", "10"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i_", ",", "2", ",", "j_"}], "}"}], "/;", 
          RowBox[{
           RowBox[{"j", "-", "1"}], "\[Equal]", 
           RowBox[{"Mod", "[", 
            RowBox[{"i", ",", "6"}], "]"}]}]}], ")"}], "\[Rule]", " ", 
        RowBox[{"1", "/", "5"}]}]}], "\[IndentingNewLine]", "}"}], ",", "6", 
     ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rw1", " ", "=", " ", 
   RowBox[{"MDPrw", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"_", ",", "1"}], "}"}], "\[Rule]", " ", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"6", "|", "5"}], ",", "2"}], "}"}], "\[Rule]", "5"}]}], 
      "}"}], ",", "6", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mdp1", "=", 
   RowBox[{"MDP", "[", 
    RowBox[{"tm1", ",", "rw1", ",", "A"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.576237112740889*^9, 3.576237243445243*^9}, {
  3.5762372930784607`*^9, 3.576237352880622*^9}}],

Cell[TextData[{
 "now, the exact value of the distance can be computed setting the option ",
 StyleBox["Exact", "Program"],
 " to ",
 StyleBox["True", "Program"]
}], "Text",
 CellChangeTimes->{{3.576237452972445*^9, 3.5762376077534237`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BDistMDP", "[", 
  RowBox[{"mdp1", ",", 
   RowBox[{"1", "/", "2"}], ",", "All", ",", 
   RowBox[{"Exact", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.576237391664822*^9, 3.576237415910408*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["24745795100", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["62081428911275", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["361379100", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["154605455648515", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["66296676700", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["24745795100", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["11058300100", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["69820257442025", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["917877800", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["688366497057175", "87428796820056"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["62081428911275", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["11058300100", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["27413470700", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["2927091348350", "404762948241"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["1062685700", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["361379100", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["69820257442025", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["27413470700", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["67703044600", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["328734000811525", "43714398410028"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["154605455648515", "21857199205014"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["917877800", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["2927091348350", "404762948241"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["67703044600", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["24667422200", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["66296676700", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["688366497057175", "87428796820056"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["1062685700", "133189519"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["328734000811525", "43714398410028"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["24667422200", "10788351039"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.576237409676887*^9, 3.576237417697775*^9}, 
   3.576296950522509*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bisimilarity Classes & Quotient", "Subsection",
 CellChangeTimes->{{3.5732750827171307`*^9, 3.573275113734194*^9}}],

Cell[TextData[{
 "Due to the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "(s,t) equals zero if and only if the states s and t are bisimilar, we can \
use the algorithm for computing ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[Lambda]"], TraditionalForm]]],
 " in order to compute the bisimilarity classes and the bisimilarity quotient \
for an MDP."
}], "Text",
 CellChangeTimes->{{3.573297892113584*^9, 3.573297910206666*^9}, {
  3.5732979476179256`*^9, 3.573298071769981*^9}, {3.5734568895504923`*^9, 
  3.573456914237727*^9}, {3.573461842194907*^9, 3.573461919789302*^9}}],

Cell[TextData[{
 "The function ",
 StyleBox["BisimClassesMDP[", "Program"],
 "\[ScriptCapitalM]",
 StyleBox["]", "Program"],
 " returns the set of bisimilarity classes of \[ScriptCapitalM], that is S/\
\[Tilde]."
}], "Text",
 CellChangeTimes->{{3.573298087185957*^9, 3.573298216473055*^9}, {
  3.573461937398999*^9, 3.573461941885407*^9}, {3.5734619794434357`*^9, 
  3.573461996871677*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BisimClassesMDP", "[", "mdp", "]"}]], "Input",
 CellChangeTimes->{{3.573455356728695*^9, 3.573455359223913*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", "5", "}"}], ",", 
   RowBox[{"{", "6", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.573455363874179*^9, 3.576236419304385*^9, 
  3.57629695295592*^9, 3.576297083326795*^9, 3.576297119358116*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BisimClassesMDP", "[", 
  RowBox[{"JoinMDP", "[", 
   RowBox[{"mdp", ",", "mdp"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5734547141797237`*^9, 3.573454723711245*^9}, {
  3.573454779828076*^9, 3.573454797367202*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "12"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5734547265743113`*^9, 3.573454809478558*^9, 
  3.5762364194513893`*^9, 3.57629695309933*^9, 3.57629712537549*^9}]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["BisimQuotientMDP[", "Program"],
 "\[ScriptCapitalM]",
 StyleBox["]", "Program"],
 " yields an MDP representing the bisimilarity quotient of \
\[ScriptCapitalM]."
}], "Text",
 CellChangeTimes->{{3.573298231390491*^9, 3.5732983059168167`*^9}, 
   3.573461990913886*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BisimQuotientMDP", "[", 
   RowBox[{"JoinMDP", "[", 
    RowBox[{"mdp", ",", "mdp"}], "]"}], "]"}], "//", "PlotMDP"}]], "Input",
 CellChangeTimes->{{3.5734548236121893`*^9, 3.57345483530309*^9}, 
   3.573454928900148*^9, {3.573455222222127*^9, 3.5734552275537453`*^9}, 
   3.573463943685329*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5582488835898263, 1.2931217454454353`}, {
       0.520235465277479, 1.2148523854822386`}, {0.5110248603945788, 
       1.1973845143025004`}, {0.5006783069954961, 1.1805645678513146`}, {
       0.48924118010669443`, 1.1644663103558497`}, {0.4767636374875006, 
       1.149160341061256}, {0.4633003996622005, 1.1347137846161983`}, {
       0.4489105099420352, 1.1211899966963026`}, {0.4336570754895235, 
       1.1086482861565172`}, {0.2103575220535931, 0.9371168582499365}, {
       0.19430743712474974`, 0.9256122270243059}, {0.17753108970292586`, 
       0.9151951289138389}, {0.16010205281083442`, 0.9059112483203072}, {
       0.14209676185452005`, 0.8978012998963467}, {0.12359417941428566`, 
       0.8909008499904953}, {0.10467544895264419`, 0.8852401606702274}, {
       0.08542353895796563, 0.8808440570070238}, {0., 0.8642931756789836}}], 
       0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5582488835898263, 1.2931217454454353`}, {
       0.5636834251409828, 1.1994368092930783`}, {0.5642121064311159, 
       1.178145785207962}, {0.5633304404422561, 1.156866455435067}, {
       0.5610422937390487, 1.1356921409204448`}, {0.5573577010367472, 
       1.1147157020635348`}, {0.5522928211937583, 1.0940291314759378`}, {
       0.5458698663466313, 1.0737231505458942`}, {0.5381170044982675, 
       1.0538868115777347`}, {0.41826477604131673`, 0.7748576425731171}, {
       0.40921600752960363`, 0.7555779382465211}, {0.39891101591822176`, 
       0.7369394201082976}, {0.3873949939635452, 0.719023827769808}, {
       0.3747184454208632, 0.7019097304361898}, {0.36093696355910376`, 
       0.6856721823394624}, {0.34611098735539014`, 0.670382393586623}, {
       0.3303055364386411, 0.6561074178662313}, {0.25861831244744926`, 
       0.5955488229338917}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {0.03801341831234736,
        0.9425625356421804}, {0.04722402319524746, 0.9600304068219188}, {
       0.05757057659433029, 0.9768503532731048}, {0.06900770348313195, 
       0.9929486107685696}, {0.0814852461023258, 1.0082545800631628`}, {
       0.09494848392762589, 1.0227011365082208`}, {0.1093383736477912, 
       1.0362249244281165`}, {0.12459180810030288`, 1.048766634967902}, {
       0.34789136153623323`, 1.2202980628744826`}, {0.3639414464650766, 
       1.231802694100113}, {0.38071779388690047`, 1.2422197922105802`}, {
       0.3981468307789919, 1.251503672804112}, {0.41615212173530625`, 
       1.2596136212280724`}, {0.4346547041755407, 1.2665140711339238`}, {
       0.4535734346371821, 1.2721747604541918`}, {0.4728253446318607, 
       1.2765708641173952`}, {0.5582488835898263, 1.2931217454454353`}}], 
       0.1], InsetBox["0.1`", {0.24712953082222336`, 1.1203584245844704`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.8`", {0.50210078094351, 0.44253347301398827`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0., 0.8642931756789836}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.33071258057130426`, 1.296399370059101},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       0.25318377089629274`, 0.6892337590862491}, {0.2526550896061596, 
       0.7105247831713654}, {0.2535367555950195, 0.7318041129442606}, {
       0.2558249022982268, 0.7529784274588827}, {0.2595094950005284, 
       0.7739548663157927}, {0.26457437484351715`, 0.7946414369033894}, {
       0.27099732969064416`, 0.8149474178334332}, {0.2787501915390081, 
       0.8347837568015926}, {0.39860241999595886`, 1.1138129258062102`}, {
       0.4076511885076719, 1.1330926301328061`}, {0.41795618011905383`, 
       1.1517311482710297`}, {0.4294722020737304, 1.169646740609519}, {
       0.4421487506164124, 1.1867608379431374`}, {0.4559302324781719, 
       1.2029983860398648`}, {0.4707562086818855, 1.2182881747927041`}, {
       0.4865616595986345, 1.2325631505130958`}, {0.5582488835898263, 
       1.2931217454454353`}}], 0.1], 
      InsetBox["0.1`", {0.35638766375434394`, 0.9666907290557032},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       1.00420156188702, 0.02077377034899297}}], 0.1], 
      InsetBox["0.2`", {0.6314099371672346, 0.3081612966414423},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.25861831244744926`, 0.5955488229338917}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.7`", {0.4600217367950289, 1.162027193686555},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.00420156188702, 0.02077377034899297}, {
       0.990398363857955, 0.1051730642369664}, {0.9879016743420681, 
       0.1244207506139478}, {0.9866844051792294, 0.1437914796965244}, {
       0.9867518947288277, 0.1632003007469146}, {0.9881038470140309, 
       0.1825620959742149}, {0.9907343330197982, 0.2017919538202531}, {
       0.9946318166947008, 0.22080554134100366`}, {0.9997792055425163, 
       0.23951947405047874`}, {1.0819706594097063`, 0.5037832610300628}, {
       1.088345379448918, 0.5221154685847205}, {1.095919474211384, 
       0.5399855547046741}, {1.1046597273460133`, 0.5573151497532601}, {
       1.1145278082897683`, 0.5740282544287199}, {1.1254804403671512`, 
       0.590051573060728}, {1.1374695905809704`, 0.6053148350500883}, {
       1.150442680262055, 0.6197511030419176}, {1.2096801965549946`, 
       0.6814332377979534}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.00420156188702, 0.02077377034899297}, {
       1.0222239503085737`, 0.07096423098511406}, {1.0266890640500914`, 
       0.08221330263881006}, {1.0318889286420436`, 0.09314217550018217}, {
       1.0378007399694402`, 0.1037029207685778}, {1.0443985716599828`, 
       0.11384922407460757`}, {1.0516534887847129`, 0.12353658859278142`}, {
       1.0595336747527495`, 0.13272253018326807`}, {1.0680045708436139`, 
       0.1413667637069795}, {1.192805378934721, 0.2605571521539257}, {
       1.2018298358563277`, 0.2686217681438374}, {1.2113682766639837`, 
       0.2760713990577498}, {1.221378870325907, 0.2828733743833841}, {
       1.2318177151740917`, 0.2889978639155984}, {1.2426390314359925`, 
       0.29441800857737616`}, {1.2537953620026747`, 0.2991100382108704}, {
       1.2652377805529587`, 0.303053375821929}, {1.3162035821147877`, 
       0.3187497414663586}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.1`", {0.8839645400724104, 0.9872774916216944},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       1.2234833945840595`, 0.5970339439099801}, {1.2259800840999464`, 
       0.5777862575329986}, {1.2271973532627851`, 0.5584155284504221}, {
       1.2271298637131869`, 0.5390067074000319}, {1.2257779114279839`, 
       0.5196449121727316}, {1.2231474254222165`, 0.5004150543266933}, {
       1.2192499417473137`, 0.4814014668059428}, {1.2141025528994984`, 
       0.4626875340964678}, {1.1319110990323085`, 0.19842374711688365`}, {
       1.1255363789930968`, 0.18009153956222596`}, {1.1179622842306307`, 
       0.1622214534422723}, {1.1092220310960013`, 0.1448918583936863}, {
       1.0993539501522465`, 0.1281787537182265}, {1.0884013180748635`, 
       0.1121554350862184}, {1.076412167861044, 0.09689217309685808}, {
       1.0634390781799596`, 0.08245590510502881}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.1562326996232866`, 0.3357727376868675},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.2096801965549946`, 0.6814332377979534}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.8`", {1.7430632354645732`, 0.6974958712780831},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.7`", {0.937226232852307, 0.8059357434558969},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       1.2981811936932344`, 0.2685592808302375}, {1.2937160799517167`, 
       0.25731020917654157`}, {1.2885162153597642`, 0.24638133631516945`}, {
       1.2826044040323679`, 0.23582059104677378`}, {1.2760065723418252`, 
       0.22567428774074402`}, {1.2687516552170952`, 0.21598692322257018`}, {
       1.2608714692490586`, 0.20680098163208355`}, {1.2524005731581942`, 
       0.1981567481083721}, {1.127599765067087, 0.07896635966142593}, {
       1.1185753081454803`, 0.0709017436715142}, {1.1090368673378244`, 
       0.06345211275760185}, {1.099026273675901, 0.056650137431967534`}, {
       1.0885874288277164`, 0.05052564789975322}, {1.0777661125658156`, 
       0.04510550323797548}, {1.0666097819991334`, 0.040413473604481207`}, {
       1.0551673634488492`, 0.03647013599342265}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.1824345671151595`, 0.14648327689699922`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.3162035821147877`, 0.3187497414663586}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.2`", {1.7963249282444698`, 0.5161541231122857},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.276446274374152, 0.7135585047582128}, {
       2.2841610491412485`, 0.6188045320803315}, {2.2851989132611186`, 
       0.5972538873772305}, {2.284808130088413, 0.5756818050122261}, {
       2.282990413410913, 0.5541828898039896}, {2.279753734863149, 
       0.5328514256950951}, {2.2751122889666298`, 0.5117809622678164}, {
       2.26908643087947, 0.49106390448047543`}, {2.2617025871284206`, 
       0.47079110742356467`}, {2.1469032034996838`, 0.18536770552027962`}, {
       2.138193756086043, 0.1656280759695602}, {2.1281969004737147`, 
       0.1465081824835372}, {2.1169564780822, 0.1280918757552338}, {
       2.1045217840191373`, 0.11045992088322285`}, {2.0909473508955716`, 
       0.09368964317459637}, {2.0762927096720523`, 0.07785458903321328}, {
       2.0606221285843564`, 0.063024203420406}, {1.9894478153023094`, 0.}}], 
       0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.276446274374152, 0.7135585047582128}, {
       2.3222629488192945`, 0.6420261852523458}, {2.332117820594771, 
       0.6254564922706586}, {2.3408543855086794`, 0.6082708687229512}, {
       2.3484343291727514`, 0.5905446825209523}, {2.3548244095854165`, 
       0.5723556722252234}, {2.3599966029152917`, 0.5537836061210756}, {
       2.3639282264002874`, 0.5349099323930839}, {2.366602037823328, 
       0.5158174219323701}, {2.3956925208320023`, 0.2424658171616885}, {
       2.397096794137135, 0.22323820057244528`}, {2.397225370854392, 
       0.20395980096961963`}, {2.396077687107888, 0.1847151641781273}, {
       2.3936587760887122`, 0.1655886879553684}, {2.3899792459817633`, 
       0.14666425186309603`}, {2.385055233443328, 0.1280248494118427}, {
       2.3789083328334457`, 0.10975222409114303`}, {2.3491724818958377`, 
       0.03017949283150867}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {1.00420156188702, 
       0.02077377034899297}}], 0.1], 
      InsetBox["0.1`", {1.4968246885946646`, 0.010386885174496485`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {
       1.9817330405352127`, 0.09475397267788135}, {1.9806951764153424`, 
       0.11630461738098231`}, {1.9810859595880486`, 0.13787669974598676`}, {
       1.9829036762655488`, 0.15937561495422334`}, {1.9861403548133127`, 
       0.1807070790631178}, {1.990781800709832, 0.20177754249039656`}, {
       1.9968076587969914`, 0.22249460027773743`}, {2.004191502548041, 
       0.24276739733464825`}, {2.118990886176778, 0.5281907992379332}, {
       2.1277003335904183`, 0.5479304287886526}, {2.137697189202747, 
       0.5670503222746757}, {2.148937611594261, 0.5854666290029791}, {
       2.161372305657324, 0.60309858387499}, {2.17494673878089, 
       0.6198688615836165}, {2.1896013800044094`, 0.6357039157249995}, {
       2.2052719610921048`, 0.6505343013378069}, {2.276446274374152, 
       0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.0797084258582066`, 0.3781922150282689},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.9894478153023094`, 0.}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.8`", {2.182744845405451, 0.5659628920244686},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       1.00420156188702, 0.02077377034899297}}], 0.1], 
      InsetBox["0.7`", {1.676687021891429, 0.02547663159025082},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       2.303355807450695, 0.10171181233737585`}, {2.293500935675219, 
       0.11828150531906301`}, {2.28476437076131, 0.13546712886677037`}, {
       2.277184427097238, 0.15319331506876935`}, {2.270794346684573, 
       0.17138232536449816`}, {2.265622153354698, 0.189954391468646}, {
       2.2616905298697025`, 0.20882806519663769`}, {2.2590167184466616`, 
       0.22792057565735152`}, {2.229926235437987, 0.501272180428033}, {
       2.228521962132854, 0.5204997970172762}, {2.2283933854155977`, 
       0.5397781966201018}, {2.229541069162102, 0.5590228334115942}, {
       2.2319599801812773`, 0.5781493096343531}, {2.2356395102882263`, 
       0.5970737457266255}, {2.240563522826661, 0.6157131481778788}, {
       2.246710423436544, 0.6339857734985785}, {2.276446274374152, 
       0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.2618224519161854`, 0.366442894521293},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3491724818958377`, 0.03017949283150867}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.2`", {2.3626071787022154`, 0.5810526384402229},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3760418755085926`, 1.1319257840489372`}, {
       2.408252451906797, 1.2131184852349586`}, {2.416168789048424, 
       1.2312930530189958`}, {2.4252706868202054`, 1.2489038100960925`}, {
       2.435518228658978, 1.2658735241225303`}, {2.4468664737555486`, 
       1.282127774062304}, {2.45926565414355, 1.297595276562135}, {
       2.472661392957901, 1.3122081985661067`}, {2.486994942905686, 
       1.3259024547989517`}, {2.6977292920822036`, 1.5142932327401317`}, {
       2.712937793080154, 1.5270087667545489`}, {2.7289545479288617`, 
       1.5386898143100072`}, {2.7457093148147385`, 1.5492851479279917`}, {
       2.7631286153569636`, 1.558748301551182}, {2.7811360568484593`, 
       1.5670377743213193`}, {2.7996526672777047`, 1.5741172125820881`}, {
       2.818597241662147, 1.579955569308838}, {2.9028777484498867`, 
       1.6029027289018873`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.3760418755085926`, 1.1319257840489372`}, {
       2.3651348133550316`, 1.226185042462109}, {2.363369137628658, 
       1.2476474621648885`}, {2.3630278657674384`, 1.2691796846183578`}, {
       2.3641124944262635`, 1.2906872798103222`}, {2.3666182669434495`, 
       1.3120759257319572`}, {2.370534194201183, 1.3332518220289522`}, {
       2.3758431028185214`, 1.3541221013649292`}, {2.38252171046562, 
       1.3745952366930871`}, {2.487365293471712, 1.6632066458832557`}, {
       2.4953843109749636`, 1.6831928518401524`}, {2.504708570765287, 
       1.7026044785012933`}, {2.5152971811062335`, 1.72135639577171}, {
       2.527103705425555, 1.739366366725774}, {2.540076365963763, 
       1.7565554082589536`}, {2.554158270846575, 1.7728481374698744`}, {
       2.5692876635854223`, 1.7881731022536076`}, {2.6381508330238224`, 
       1.8534543070243594`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.1`", {2.5896620114120195`, 1.15823061683005},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       2.8706671720516828`, 1.5217100277158662`}, {2.862750834910056, 
       1.503535459931829}, {2.8536489371382743`, 1.4859247028547322`}, {
       2.8434013952995016`, 1.4689549888282945`}, {2.832053150202931, 
       1.4527007388885207`}, {2.81965396981493, 1.4372332363886897`}, {
       2.806258231000579, 1.422620314384718}, {2.7919246810527936`, 
       1.408926058151873}, {2.581190331876276, 1.220535280210693}, {
       2.5659818308783255`, 1.2078197461962759`}, {2.549965076029618, 
       1.1961386986408176`}, {2.5332103091437412`, 1.185543365022833}, {
       2.515791008601516, 1.1760802113996427`}, {2.4977835671100204`, 
       1.1677907386295054`}, {2.479266956680775, 1.1607113003687366`}, {
       2.4603223822963325`, 1.1548729436419867`}, {2.3760418755085926`, 
       1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.674599414335879, 1.3281070180114356`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.9028777484498867`, 1.6029027289018873`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.8`", {2.3807483562119076`, 2.0238402956578208`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       2.276446274374152, 0.7135585047582128}}], 0.1], 
      InsetBox["0.7`", {2.457298553698987, 1.2835064058912862`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       2.6490578951773838`, 1.759195048611188}, {2.6508235709037575`, 
       1.7377326289084085`}, {2.651164842764977, 1.7162004064549392`}, {
       2.650080214106152, 1.6946928112629749`}, {2.647574441588966, 
       1.6733041653413399`}, {2.6436585143312326`, 1.6521282690443448`}, {
       2.638349605713894, 1.6312579897083679`}, {2.6316709980667956`, 
       1.61078485438021}, {2.5268274150607035`, 1.3221734451900413`}, {
       2.518808397557452, 1.3021872392331446`}, {2.5094841377671284`, 
       1.2827756125720038`}, {2.498895527426182, 1.264023695301587}, {
       2.48708900310686, 1.246013724347523}, {2.4741163425686525`, 
       1.2288246828143434`}, {2.4600344376858403`, 1.2125319536034227`}, {
       2.444905044946993, 1.1972069888196895`}, {2.3760418755085926`, 
       1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.5609296165169657`, 1.4731340892592686`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{2.6381508330238224`, 1.8534543070243594`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.2`", {2.248384898498876, 2.149116084719057},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.858618963973929, 2.4447778624137544`}, {
       1.8818342107669963`, 2.397672222456342}, {1.8867460489304835`, 
       2.3868129799929614`}, {1.8909283764403708`, 2.3756524496461173`}, {
       1.8943628516118356`, 2.3642395761552137`}, {1.8970344124821372`, 
       2.3526244109157926`}, {1.8989313428651686`, 2.340857892478093}, {
       1.9000453237330357`, 2.3289916231549737`}, {1.9003714696993297`, 
       2.3170776427188873`}, {1.8993943886918638`, 2.1471363767948857`}, {
       1.8989312694366236`, 2.13522693425637}, {1.8976809159790353`, 
       2.1233742587249176`}, {1.8956488117703543`, 2.1116303303571256`}, {
       1.8928438686461158`, 2.1000466523966255`}, {1.889278387743093, 
       2.088674025305537}, {1.8849680055524038`, 2.0775623239779737`}, {
       1.8799316253453537`, 2.0667602790126525`}, {1.8561762614552637`, 
       2.0199246976037513`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.858618963973929, 2.4447778624137544`}, {
       1.859507836366445, 2.3581157888294078`}, {1.8590582161414022`, 
       2.338451892352433}, {1.8573080884365558`, 2.3188608730828624`}, {
       1.8542651284735818`, 2.299428647845703}, {1.8499426812170805`, 
       2.2802404370714093`}, {1.8443597028499557`, 2.2613803910599017`}, {
       1.8375406776406766`, 2.242931220937667}, {1.8295155105670067`, 
       2.2249738359263787`}, {1.70666975588375, 1.9728503855042967`}, {
       1.6974736414838414`, 1.9554635380917338`}, {1.6871469095098508`, 
       1.9387234786610947`}, {1.6757348480609675`, 1.9227036210933486`}, {
       1.663287504971507, 1.9074742208091218`}, {1.6498594683250853`, 
       1.8931020666620806`}, {1.635509627057437, 1.8796501880350167`}, {
       1.6203009126977541`, 1.86717757842317}, {1.551504577265786, 
       1.8144692363585486`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.1`", {2.1161090684819284`, 1.5759252408263442`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       1.8329610146621964`, 2.0670303375611643`}, {1.8280491764987092`, 
       2.0778895800245447`}, {1.823866848988822, 2.0890501103713888`}, {
       1.8204323738173571`, 2.1004629838622924`}, {1.8177608129470555`, 
       2.1120781491017135`}, {1.815863882564024, 2.123844667539413}, {
       1.814749901696157, 2.1357109368625324`}, {1.814423755729863, 
       2.147624917298619}, {1.8154008367373293`, 2.3175661832226204`}, {
       1.8158639559925696`, 2.329475625761136}, {1.8171143094501578`, 
       2.3413283012925885`}, {1.819146413658839, 2.3530722296603805`}, {
       1.8219513567830774`, 2.3646559076208806`}, {1.8255168376861002`, 
       2.376028534711969}, {1.8298272198767893`, 2.3871402360395324`}, {
       1.8348636000838394`, 2.3979422810048536`}, {1.858618963973929, 
       2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.8256993068112264`, 2.2325335301085074`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.8561762614552637`, 2.0199246976037513`}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.8`", {1.2588007112989361`, 1.8742151310214847`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       2.3760418755085926`, 1.1319257840489372`}}], 0.1], 
      InsetBox["0.7`", {1.9637732263871892`, 1.473197510203743},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       1.5506157048732705`, 1.9011313099428957`}, {1.5510653250983133`, 
       1.9207952064198708`}, {1.5528154528031597`, 1.9403862256894413`}, {
       1.5558584127661337`, 1.9598184509266008`}, {1.560180860022635, 
       1.9790066617008946`}, {1.5657638383897599`, 1.9978667077124017`}, {
       1.5725828635990389`, 2.016315877834637}, {1.5806080306727086`, 
       2.0342732628459252`}, {1.7034537853559657`, 2.2863967132680068`}, {
       1.7126498997558741`, 2.3037835606805697`}, {1.7229766317298647`, 
       2.3205236201112087`}, {1.734388693178748, 2.336543477678955}, {
       1.7468360362682085`, 2.3517728779631817`}, {1.7602640729146302`, 
       2.366145032110223}, {1.7746139141822785`, 2.3795969107372867`}, {
       1.7898226285419614`, 2.392069520349134}, {1.858618963973929, 
       2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.6580344272995702`, 2.152537361930196},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{1.551504577265786, 1.8144692363585486`}, {
       0.6614251611426085, 1.7285055644392184`}}], 0.1], 
      InsetBox["0.2`", {1.1064648692041974`, 1.7714874003988834`},
       Background->GrayLevel[1]]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.6614251611426085, 1.7285055644392184`}, {
       0.6111998990987786, 1.7969807663185913`}, {0.6003220714321695, 
       1.812890154569963}, {0.590521090166301, 1.8294846276108108`}, {
       0.581839937709629, 1.8466914100323255`}, {0.574316685437931, 
       1.8644350411300947`}, {0.567984326731491, 1.882637705838601}, {
       0.5628706322819392, 1.9012195759908208`}, {0.5589980283033038, 
       1.9200991604063207`}, {0.5127229072829786, 2.190982328702565}, {
       0.5101083771610531, 2.2100768305687795`}, {0.5087633869724042, 
       2.2293025105481656`}, {0.508693835199652, 2.2485750540188194`}, {
       0.5099000268635516, 2.2678099408380152`}, {0.5123766721853179, 
       2.2869228160070603`}, {0.5161129097850611, 2.3058298596119076`}, {
       0.5210923543145956, 2.324448154417142}, {0.5457373585917956, 
       2.4057134851798287`}}], 0.1]}, 
     {RGBColor[1, 0, 0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.6614251611426085, 1.7285055644392184`}, {
       0.6498832966371474, 1.8214906315925277`}, {0.6479640560257307, 
       1.8426688018601867`}, {0.6474507424065128, 1.8639275621612668`}, {
       0.6483456069271136, 1.8851736817575657`}, {0.6506447251404501, 
       1.9063139853469553`}, {0.654338014215482, 1.9272557616856214`}, {
       0.6594092771556777, 1.9479071701751618`}, {0.6658362738312817, 
       1.9681776436314538`}, {0.7669984407345833, 2.2540196935866663`}, {
       0.7747529854171711, 2.2738203354241477`}, {0.7838010703887499, 
       2.293064309513653}, {0.7941030150833192, 2.3116672210040754`}, {
       0.8056136401068223, 2.329547486437753}, {0.8182824653723245, 
       2.346626691536429}, {0.8320539314814914, 2.36282993508871}, {
       0.8468676433814926, 2.3780861574308965`}, {0.9143305784008628, 
       2.4431106893272503`}}], 0.1]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.8`", {0.5519931210908109, 1.849417615312632},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.1`", {1.2021781612828624`, 2.4252456737967916`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.5457373585917956, 2.4057134851798287`}, {
       0.5959626206356257, 2.337238283300456}, {0.6068404483022347, 
       2.3213288950490845`}, {0.6166414295681033, 2.3047344220082366`}, {
       0.6253225820247752, 2.287527639586722}, {0.6328458342964732, 
       2.269784008488953}, {0.6391781930029133, 2.251581343780447}, {
       0.644291887452465, 2.2329994736282273`}, {0.6481644914311006, 
       2.214119889212727}, {0.6944396124514257, 1.943236720916483}, {
       0.6970541425733512, 1.9241422190502684`}, {0.6983991327620003, 
       1.9049165390708822`}, {0.6984686845347523, 1.8856439956002287`}, {
       0.6972624928708526, 1.866409108781033}, {0.6947858475490865, 
       1.8472962336119878`}, {0.6910496099493433, 1.8283891900071407`}, {
       0.6860701654198087, 1.8097708952019063`}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.6541077608088175, 2.0757409948285463`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       0.5582488835898263, 1.2931217454454353`}}], 0.1], 
      InsetBox["0.2`", {0.7362897309953446, 1.8681162173863428`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       1.858618963973929, 2.4447778624137544`}}], 0.1], 
      InsetBox["0.7`", {1.386474771187396, 2.4439442758705026`},
       Background->GrayLevel[1]]}, 
     {GrayLevel[0], Arrowheads[0.02], 
      ArrowBox[BezierCurveBox[{{0.9143305784008628, 2.4431106893272503`}, {
       0.9258724429063241, 2.350125622173941}, {0.9277916835177409, 
       2.328947451906282}, {0.9283049971369586, 2.3076886916052017`}, {
       0.927410132616358, 2.2864425720089034`}, {0.9251110144030213, 
       2.2653022684195134`}, {0.9214177253279895, 2.244360492080847}, {
       0.9163464623877937, 2.2237090835913067`}, {0.9099194657121898, 
       2.203438610135015}, {0.808757298808888, 1.9175965601798026`}, {
       0.8010027541263004, 1.8977959183423214`}, {0.7919546691547217, 
       1.878551944252816}, {0.7816527244601523, 1.8599490327623935`}, {
       0.7701420994366492, 1.8420687673287157`}, {0.757473274171147, 
       1.8249895622300398`}, {0.7437018080619802, 1.808786318677759}, {
       0.728888096161979, 1.7935300963355727`}, {0.6614251611426085, 
       1.7285055644392184`}}], 0.1], 
      InsetBox["0.1`", {0.8411945771074257, 2.066938846988717},
       Background->GrayLevel[1]]}}, {
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.5582488835898263, 1.2931217454454353`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["1", {0.5582488835898263, 1.2931217454454353`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0., 0.8642931756789836}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0., 0.8642931756789836}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.25861831244744926`, 0.5955488229338917}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.25861831244744926`, 0.5955488229338917}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.00420156188702, 0.02077377034899297}, 0.1], 
      {GrayLevel[0], InsetBox["2", {1.00420156188702, 0.02077377034899297}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.2096801965549946`, 0.6814332377979534}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.2096801965549946`, 0.6814332377979534}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.3162035821147877`, 0.3187497414663586}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.3162035821147877`, 0.3187497414663586}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.276446274374152, 0.7135585047582128}, 0.1], 
      {GrayLevel[0], InsetBox["3", {2.276446274374152, 0.7135585047582128}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.9894478153023094`, 0.}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.9894478153023094`, 0.}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.3491724818958377`, 0.03017949283150867}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.3491724818958377`, 0.03017949283150867}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.3760418755085926`, 1.1319257840489372`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["4", {2.3760418755085926`, 1.1319257840489372`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.9028777484498867`, 1.6029027289018873`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.9028777484498867`, 1.6029027289018873`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{2.6381508330238224`, 1.8534543070243594`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {2.6381508330238224`, 1.8534543070243594`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.858618963973929, 2.4447778624137544`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["5", {1.858618963973929, 2.4447778624137544`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.8561762614552637`, 2.0199246976037513`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {1.8561762614552637`, 2.0199246976037513`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{1.551504577265786, 1.8144692363585486`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {1.551504577265786, 1.8144692363585486`}]}}, 
     {GrayLevel[1], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.6614251611426085, 1.7285055644392184`}, 0.1], 
      {GrayLevel[0], 
       InsetBox["6", {0.6614251611426085, 1.7285055644392184`}]}}, 
     {Hue[
       NCache[
        Rational[1, 2], 0.5], 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.5457373585917956, 2.4057134851798287`}, 0.1], 
      {GrayLevel[0], Opacity[1], InsetBox[
        RowBox[{"-", "1"}], {0.5457373585917956, 2.4057134851798287`}]}}, 
     {Hue[1, 1, 1], Opacity[0.3], EdgeForm[GrayLevel[0]], 
      DiskBox[{0.9143305784008628, 2.4431106893272503`}, 0.1], 
      {GrayLevel[0], Opacity[1], 
       InsetBox["5", {0.9143305784008628, 2.4431106893272503`}]}}}},
   Annotation[#, 
    VertexCoordinateRules -> {{0.5582488835898263, 1.2931217454454353`}, {0., 
     0.8642931756789836}, {0.25861831244744926`, 0.5955488229338917}, {
     1.00420156188702, 0.02077377034899297}, {1.2096801965549946`, 
     0.6814332377979534}, {1.3162035821147877`, 0.3187497414663586}, {
     2.276446274374152, 0.7135585047582128}, {1.9894478153023094`, 0.}, {
     2.3491724818958377`, 0.03017949283150867}, {2.3760418755085926`, 
     1.1319257840489372`}, {2.9028777484498867`, 1.6029027289018873`}, {
     2.6381508330238224`, 1.8534543070243594`}, {1.858618963973929, 
     2.4447778624137544`}, {1.8561762614552637`, 2.0199246976037513`}, {
     1.551504577265786, 1.8144692363585486`}, {0.6614251611426085, 
     1.7285055644392184`}, {0.5457373585917956, 2.4057134851798287`}, {
     0.9143305784008628, 2.4431106893272503`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{3.573454941818267*^9, 3.573455061570986*^9, 
  3.57345520232611*^9, 3.573455242135882*^9, 3.576236419606629*^9, 
  3.576296953232345*^9, 3.576297133787121*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{990, 681},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 172, 6, 92, "Title"],
Cell[754, 30, 193, 4, 81, "Subtitle"],
Cell[950, 36, 170, 3, 29, "Subsubtitle"],
Cell[1123, 41, 1303, 29, 68, "Text"],
Cell[CellGroupData[{
Cell[2451, 74, 248, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[2724, 81, 168, 4, 35, "Subsubsection"],
Cell[2895, 87, 596, 18, 53, "Text"],
Cell[3494, 107, 887, 21, 49, "Text"],
Cell[4384, 130, 4458, 153, 160, "Text"],
Cell[8845, 285, 1262, 35, 72, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10144, 325, 118, 1, 35, "Subsubsection"],
Cell[10265, 328, 1846, 42, 127, "Text"],
Cell[12114, 372, 1047, 30, 26, "DisplayFormula"],
Cell[13164, 404, 844, 20, 32, "Text"],
Cell[14011, 426, 1872, 49, 49, "DisplayFormula"],
Cell[15886, 477, 517, 11, 32, "Text"],
Cell[16406, 490, 604, 16, 51, "Text"],
Cell[17013, 508, 382, 10, 32, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17444, 524, 107, 1, 44, "Subsection"],
Cell[17554, 527, 332, 6, 30, "Text"],
Cell[17889, 535, 362, 9, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18288, 549, 196, 4, 44, "Subsection"],
Cell[CellGroupData[{
Cell[18509, 557, 82, 1, 35, "Subsubsection"],
Cell[18594, 560, 2325, 64, 117, "Text"],
Cell[20922, 626, 1312, 28, 111, "Text"],
Cell[22237, 656, 367, 8, 49, "Text"],
Cell[22607, 666, 2184, 58, 216, "Input"],
Cell[24794, 726, 417, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[25236, 739, 1438, 31, 46, "Input"],
Cell[26677, 772, 2056, 67, 63, "Output"],
Cell[28736, 841, 796, 25, 28, "Output"]
}, Open  ]],
Cell[29547, 869, 118, 1, 30, "Text"],
Cell[29668, 872, 203, 5, 28, "Input"],
Cell[29874, 879, 2911, 80, 114, "Text"],
Cell[32788, 961, 573, 12, 31, "Text"],
Cell[33364, 975, 3095, 83, 166, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36496, 1063, 110, 1, 35, "Subsubsection"],
Cell[36609, 1066, 1045, 18, 89, "Text"],
Cell[CellGroupData[{
Cell[37679, 1088, 128, 2, 28, "Input"],
Cell[37810, 1092, 35842, 584, 322, "Output"]
}, Open  ]],
Cell[73667, 1679, 1566, 42, 72, "Text"],
Cell[CellGroupData[{
Cell[75258, 1725, 384, 7, 28, "Input"],
Cell[75645, 1734, 72395, 1324, 646, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[148101, 3065, 128, 3, 44, "Subsection"],
Cell[148232, 3070, 831, 20, 52, "Text"],
Cell[CellGroupData[{
Cell[149088, 3094, 481, 10, 28, "Input"],
Cell[149572, 3106, 550, 11, 28, "Output"]
}, Open  ]],
Cell[150137, 3120, 190, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[150352, 3128, 382, 11, 28, "Input"],
Cell[150737, 3141, 494, 14, 28, "Output"]
}, Open  ]],
Cell[151246, 3158, 288, 7, 31, "Text"],
Cell[CellGroupData[{
Cell[151559, 3169, 215, 4, 28, "Input"],
Cell[151777, 3175, 3991, 120, 114, "Output"]
}, Open  ]],
Cell[155783, 3298, 615, 12, 50, "Text"],
Cell[156401, 3312, 219, 4, 28, "Input"],
Cell[156623, 3318, 289, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[156937, 3328, 723, 20, 28, "Input"],
Cell[157663, 3350, 4031, 126, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161731, 3481, 111, 1, 35, "Subsubsection"],
Cell[161845, 3484, 528, 9, 68, "Text"],
Cell[162376, 3495, 163, 3, 30, "Text"],
Cell[162542, 3500, 2722, 78, 166, "Input"],
Cell[165267, 3580, 241, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[165533, 3590, 236, 5, 28, "Input"],
Cell[165772, 3597, 4761, 142, 314, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[170594, 3746, 121, 1, 44, "Subsection"],
Cell[170718, 3749, 682, 16, 51, "Text"],
Cell[171403, 3767, 390, 10, 31, "Text"],
Cell[CellGroupData[{
Cell[171818, 3781, 136, 2, 28, "Input"],
Cell[171957, 3785, 389, 10, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[172383, 3800, 247, 5, 28, "Input"],
Cell[172633, 3807, 545, 16, 28, "Output"]
}, Open  ]],
Cell[173193, 3826, 312, 9, 31, "Text"],
Cell[CellGroupData[{
Cell[173530, 3839, 330, 7, 28, "Input"],
Cell[173863, 3848, 35835, 583, 322, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
